<?php

namespace WPStaging\Pro\Backup\Task\Tasks\JobRestore;

use RuntimeException;
use WPStaging\Backup\Task\Tasks\JobRestore\RestoreRequirementsCheckTask as BasicRestoreRequirementsCheckTask;
use WPStaging\Core\WPStaging;

class RestoreRequirementsCheckTask extends BasicRestoreRequirementsCheckTask
{
    /**
     * Version 2.16.0 is the first version where we introduce backups for free version.
     * @var string
     */
    const FREE_BACKUP_RESTORE_FIRST_VERSION = '2.16.0';

    protected function cannotRestoreOnMultisite()
    {
        // no-op
    }

    protected function cannotMigrate()
    {
        // no-op
    }

    protected function cannotRestoreMultipartBackup()
    {
        // no-op
    }

    protected function cannotRestoreIfBackupGeneratedOnProVersion()
    {
        // no-op
    }

    /**
     * Disallows backups generated in newer versions of WP STAGING to be restored
     * using older versions of WP STAGING.
     */
    protected function cannotRestoreIfBackupGeneratedOnNewerWPStagingVersion()
    {
        $metadata       = $this->jobDataDto->getBackupMetadata();
        $isCreatedOnPro = $metadata->getCreatedOnPro();
        $backupVersion  = $metadata->getVersion();
        if ($isCreatedOnPro && version_compare($backupVersion, $this->getCurrentWpStagingVersion(), '<=')) {
            return;
        }

        if (!$isCreatedOnPro && version_compare($backupVersion, $this->getCompatibleFreeVersion(), '<=')) {
            return;
        }

        $wpstgVersion = "WP STAGING";
        if ($isCreatedOnPro) {
            $wpstgVersion = " PRO";
        }

        $wpstgVersion .= " version: " . $backupVersion;
        if ($this->isDevVersion()) {
            $this->logger->warning(sprintf("Backup generated on a newer %s. Allowed to continue due to WPSTG_DEV...", esc_html($wpstgVersion)));
            return;
        }

        throw new RuntimeException(sprintf("This backup was generated on a newer version of %s. Please upgrade WP STAGING PRO to restore this Backup.", esc_html($wpstgVersion)));
    }

    /**
     * @return string
     */
    protected function getCompatibleFreeVersion()
    {
        return defined('WPSTG_COMPATIBLE_FREE_VERSION') ? WPSTG_COMPATIBLE_FREE_VERSION : self::FREE_BACKUP_RESTORE_FIRST_VERSION;
    }
}
