(function () {
  'use strict';

  function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
      var info = gen[key](arg);
      var value = info.value;
    } catch (error) {
      reject(error);
      return;
    }

    if (info.done) {
      resolve(value);
    } else {
      Promise.resolve(value).then(_next, _throw);
    }
  }

  function _asyncToGenerator(fn) {
    return function () {
      var self = this,
          args = arguments;
      return new Promise(function (resolve, reject) {
        var gen = fn.apply(self, args);

        function _next(value) {
          asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
        }

        function _throw(err) {
          asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
        }

        _next(undefined);
      });
    };
  }

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _createForOfIteratorHelperLoose(o, allowArrayLike) {
    var it;

    if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
      if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
        if (it) o = it;
        var i = 0;
        return function () {
          if (i >= o.length) return {
            done: true
          };
          return {
            done: false,
            value: o[i++]
          };
        };
      }

      throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }

    it = o[Symbol.iterator]();
    return it.next.bind(it);
  }

  /**
   * Polyfills the `Element.prototype.closest` function if not available in the browser.
   *
   * @return {Function} A function that will return the closest element, by selector, to this element.
   */
  function polyfillClosest() {
    if (Element.prototype.closest) {
      if (!Element.prototype.matches) {
        Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
      }

      Element.prototype.closest = function (s) {
        var el = this;

        do {
          if (Element.prototype.matches.call(el, s)) return el;
          el = el.parentElement || el.parentNode;
        } while (el !== null && el.nodeType === 1);

        return null;
      };
    }

    return function (element, selector) {
      return element instanceof Element ? element.closest(selector) : null;
    };
  }

  polyfillClosest();

  /**
   * This is a namespaced port of https://github.com/tristen/hoverintent,
   * with slight modification to accept selector with dynamically added element in dom,
   * instead of just already present element.
   *
   * @param {HTMLElement} parent
   * @param {string} selector
   * @param {CallableFunction} onOver
   * @param {CallableFunction} onOut
   *
   * @return {object}
   */

  function wpstgHoverIntent (parent, selector, onOver, onOut) {
    var x;
    var y;
    var pX;
    var pY;
    var mouseOver = false;
    var focused = false;
    var h = {};
    var state = 0;
    var timer = 0;
    var options = {
      sensitivity: 7,
      interval: 100,
      timeout: 0,
      handleFocus: false
    };

    function delay(el, e) {
      if (timer) {
        timer = clearTimeout(timer);
      }

      state = 0;
      return focused ? undefined : onOut(el, e);
    }

    function tracker(e) {
      x = e.clientX;
      y = e.clientY;
    }

    function compare(el, e) {
      if (timer) timer = clearTimeout(timer);

      if (Math.abs(pX - x) + Math.abs(pY - y) < options.sensitivity) {
        state = 1;
        return focused ? undefined : onOver(el, e);
      } else {
        pX = x;
        pY = y;
        timer = setTimeout(function () {
          compare(el, e);
        }, options.interval);
      }
    } // Public methods


    h.options = function (opt) {
      var focusOptionChanged = opt.handleFocus !== options.handleFocus;
      options = Object.assign({}, options, opt);

      if (focusOptionChanged) {
        options.handleFocus ? addFocus() : removeFocus();
      }

      return h;
    };

    function dispatchOver(el, e) {
      mouseOver = true;

      if (timer) {
        timer = clearTimeout(timer);
      }

      el.removeEventListener('mousemove', tracker, false);

      if (state !== 1) {
        pX = e.clientX;
        pY = e.clientY;
        el.addEventListener('mousemove', tracker, false);
        timer = setTimeout(function () {
          compare(el, e);
        }, options.interval);
      }

      return this;
    }
    /**
     * Newly added method,
     * A wrapper around dispatchOver to support dynamically added elements to dom
     */


    function onMouseOver(event) {
      if (event.target.matches(selector + ', ' + selector + ' *')) {
        dispatchOver(event.target.closest(selector), event);
      }
    }

    function dispatchOut(el, e) {
      mouseOver = false;

      if (timer) {
        timer = clearTimeout(timer);
      }

      el.removeEventListener('mousemove', tracker, false);

      if (state === 1) {
        timer = setTimeout(function () {
          delay(el, e);
        }, options.timeout);
      }

      return this;
    }
    /**
     * Newly added method,
     * A wrapper around dispatchOut to support dynamically added elements to dom
     */


    function onMouseOut(event) {
      if (event.target.matches(selector + ', ' + selector + ' *')) {
        dispatchOut(event.target.closest(selector), event);
      }
    }

    function dispatchFocus(el, e) {
      if (!mouseOver) {
        focused = true;
        onOver(el, e);
      }
    }
    /**
     * Newly added method,
     * A wrapper around dispatchFocus to support dynamically added elements to dom
     */


    function onFocus(event) {
      if (event.target.matches(selector + ', ' + selector + ' *')) {
        dispatchFocus(event.target.closest(selector), event);
      }
    }

    function dispatchBlur(el, e) {
      if (!mouseOver && focused) {
        focused = false;
        onOut(el, e);
      }
    }
    /**
     * Newly added method,
     * A wrapper around dispatchBlur to support dynamically added elements to dom
     */


    function onBlur(event) {
      if (event.target.matches(selector + ', ' + selector + ' *')) {
        dispatchBlur(event.target.closest(selector), event);
      }
    }
    /**
     * Modified to support dynamically added element
     */

    function addFocus() {
      parent.addEventListener('focus', onFocus, false);
      parent.addEventListener('blur', onBlur, false);
    }
    /**
     * Modified to support dynamically added element
     */


    function removeFocus() {
      parent.removeEventListener('focus', onFocus, false);
      parent.removeEventListener('blur', onBlur, false);
    }
    /**
     * Modified to support dynamically added element
     */


    h.remove = function () {
      if (!parent) {
        return;
      }

      parent.removeEventListener('mouseover', onMouseOver, false);
      parent.removeEventListener('mouseout', onMouseOut, false);
      removeFocus();
    };
    /**
     * Modified to support dynamically added element
     */


    if (parent) {
      parent.addEventListener('mouseover', onMouseOver, false);
      parent.addEventListener('mouseout', onMouseOut, false);
    }

    return h;
  }

  var WPStagingCommon = (function ($) {
    var WPStagingCommon = {
      continueErrorHandle: true,
      retry: {
        currentDelay: 0,
        count: 0,
        max: 10,
        retryOnErrors: [401, 403, 404, 429, 502, 503, 504],
        performingRequest: false,
        incrementRetry: function incrementRetry(incrementRatio) {
          if (incrementRatio === void 0) {
            incrementRatio = 1.25;
          }

          WPStagingCommon.retry.performingRequest = true;

          if (WPStagingCommon.retry.currentDelay === 0) {
            // start with a delay of 1sec
            WPStagingCommon.retry.currentDelay = 1000;
            WPStagingCommon.retry.count = 1;
          }

          WPStagingCommon.retry.currentDelay += 500 * WPStagingCommon.retry.count * incrementRatio;
          WPStagingCommon.retry.count++;
        },
        canRetry: function canRetry() {
          return WPStagingCommon.retry.count < WPStagingCommon.retry.max;
        },
        reset: function reset() {
          WPStagingCommon.retry.currentDelay = 0;
          WPStagingCommon.retry.count = 0;
          WPStagingCommon.retry.performingRequest = false;
        }
      },
      memoryExhaustArticleLink: 'https://wp-staging.com/docs/php-fatal-error-allowed-memory-size-of-134217728-bytes-exhausted/',
      cache: {
        elements: [],
        get: function get(selector) {
          // It is already cached!
          if ($.inArray(selector, this.elements) !== -1) {
            return this.elements[selector];
          } // Create cache and return


          this.elements[selector] = $(selector);
          return this.elements[selector];
        },
        refresh: function refresh(selector) {
          selector.elements[selector] = $(selector);
        }
      },
      setJobId: function setJobId(jobId) {
        localStorage.setItem('jobIdBeingProcessed', jobId);
      },
      getJobId: function getJobId() {
        return localStorage.getItem('jobIdBeingProcessed');
      },
      listenTooltip: function listenTooltip() {
        wpstgHoverIntent(document, '.wpstg--tooltip', function (target, event) {
          target.querySelector('.wpstg--tooltiptext').style.visibility = 'visible';
        }, function (target, event) {
          target.querySelector('.wpstg--tooltiptext').style.visibility = 'hidden';
        });
      },
      // Get the custom themed Swal Modal for WP Staging
      // Easy to maintain now in one place now
      getSwalModal: function getSwalModal(isContentCentered, customClasses) {
        if (isContentCentered === void 0) {
          isContentCentered = false;
        }

        if (customClasses === void 0) {
          customClasses = {};
        }

        // common style for all swal modal used in WP Staging
        var defaultCustomClasses = {
          confirmButton: 'wpstg--btn--confirm wpstg-blue-primary wpstg-button wpstg-link-btn wpstg-100-width',
          cancelButton: 'wpstg--btn--cancel wpstg-blue-primary wpstg-link-btn wpstg-100-width',
          actions: 'wpstg--modal--actions',
          popup: isContentCentered ? 'wpstg-swal-popup centered-modal' : 'wpstg-swal-popup'
        }; // If a attribute exists in both default and additional attributes,
        // The class(es) of the additional attribute will overrite the default one.

        var options = {
          customClass: Object.assign(defaultCustomClasses, customClasses),
          buttonsStyling: false,
          reverseButtons: true,
          showClass: {
            popup: 'wpstg--swal2-show wpstg-swal-show'
          }
        };
        return wpstgSwal.mixin(options);
      },
      showSuccessModal: function showSuccessModal(htmlContent) {
        this.getSwalModal().fire({
          showConfirmButton: false,
          showCancelButton: true,
          cancelButtonText: 'OK',
          icon: 'success',
          title: 'Success!',
          html: '<div class="wpstg--grey" style="text-align: left; margin-top: 8px;">' + htmlContent + '</div>'
        });
      },
      showWarningModal: function showWarningModal(htmlContent) {
        this.getSwalModal().fire({
          showConfirmButton: false,
          showCancelButton: true,
          cancelButtonText: 'OK',
          icon: 'warning',
          title: '',
          html: '<div class="wpstg--grey" style="text-align: left; margin-top: 8px;">' + htmlContent + '</div>'
        });
      },
      showErrorModal: function showErrorModal(htmlContent) {
        this.getSwalModal().fire({
          showConfirmButton: false,
          showCancelButton: true,
          cancelButtonText: 'OK',
          icon: 'error',
          title: 'Error!',
          html: '<div class="wpstg--grey" style="text-align: left; margin-top: 8px;">' + htmlContent + '</div>'
        });
      },
      getSwalContainer: function getSwalContainer() {
        return wpstgSwal.getContainer();
      },
      closeSwalModal: function closeSwalModal() {
        wpstgSwal.close();
      },

      /**
       * Treats a default response object generated by WordPress's
       * wp_send_json_success() or wp_send_json_error() functions in
       * PHP, parses it in JavaScript, and either throws if it's an error,
       * or returns the data if the response is successful.
       *
       * @param {object} response
       * @return {*}
       */
      getDataFromWordPressResponse: function getDataFromWordPressResponse(response) {
        if (typeof response !== 'object') {
          throw new Error('Unexpected response (ERR 1341)');
        }

        if (!response.hasOwnProperty('success')) {
          throw new Error('Unexpected response (ERR 1342)');
        }

        if (!response.hasOwnProperty('data')) {
          throw new Error('Unexpected response (ERR 1343)');
        }

        if (response.success === false) {
          if (response.data instanceof Array && response.data.length > 0) {
            throw new Error(response.data.shift());
          } else {
            throw new Error('Response was not successful');
          }
        } else {
          // Successful response. Return the data.
          return response.data;
        }
      },
      isLoading: function isLoading(_isLoading) {
        if (!_isLoading || _isLoading === false) {
          WPStagingCommon.cache.get('.wpstg-loader').hide();
        } else {
          WPStagingCommon.cache.get('.wpstg-loader').show();
        }
      },

      /**
       * Convert the given url to make it slug compatible
       * @param {string} url
       * @return {string}
       */
      slugify: function slugify(url) {
        return url.toString().toLowerCase().normalize('NFD').replace(/[\u0300-\u036f]/g, '').replace(/\s+/g, '-').replace(/&/g, '-and-').replace(/[^a-z0-9\-]/g, '').replace(/-+/g, '-').replace(/^-*/, '').replace(/-*$/, '');
      },
      showAjaxFatalError: function showAjaxFatalError(response, prependMessage, appendMessage) {
        prependMessage = prependMessage ? prependMessage + '<br/><br/>' : 'Something went wrong! <br/><br/>';
        appendMessage = appendMessage ? appendMessage + '<br/><br/>' : '<br/><br/>Please try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.';

        if (response === false) {
          WPStagingCommon.showError(prependMessage + ' Error: No response.' + appendMessage);
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          return;
        }

        if (typeof response.error !== 'undefined' && response.error) {
          WPStagingCommon.showError(prependMessage + ' Error: ' + response.message + appendMessage);
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          return;
        }
      },
      handleFetchErrors: function handleFetchErrors(response) {
        if (!response.ok) {
          WPStagingCommon.showError('Error: ' + response.status + ' - ' + response.statusText + '. Please try again or contact support.');
        }

        return response;
      },
      showError: function showError(message) {
        // If retry request no need to show Error;
        if (WPStagingCommon.retry.performingRequest) {
          return;
        }

        WPStagingCommon.cache.get('#wpstg-try-again').css('display', 'inline-block');
        WPStagingCommon.cache.get('#wpstg-cancel-cloning').text('Reset');
        WPStagingCommon.cache.get('#wpstg-resume-cloning').show();
        WPStagingCommon.cache.get('#wpstg-error-wrapper').show();
        WPStagingCommon.cache.get('#wpstg-error-details').show().html(message);
        WPStagingCommon.cache.get('#wpstg-removing-clone').removeClass('loading');
        WPStagingCommon.cache.get('.wpstg-loader').hide();
        $('.wpstg--modal--process--generic-problem').show().html(message);
      },
      resetErrors: function resetErrors() {
        WPStagingCommon.cache.get('#wpstg-error-details').hide().html('');
      },

      /**
       * Ajax Requests
       * @param {Object} data
       * @param {Function} callback
       * @param {string} dataType
       * @param {bool} showErrors
       * @param {int} tryCount
       * @param {float} incrementRatio
       * @param {function} errorCallback
       */
      ajax: function ajax(data, callback, dataType, showErrors, tryCount, incrementRatio, errorCallback) {
        if (incrementRatio === void 0) {
          incrementRatio = null;
        }

        if (errorCallback === void 0) {
          errorCallback = null;
        }

        if ('undefined' === typeof dataType) {
          dataType = 'json';
        }

        if (false !== showErrors) {
          showErrors = true;
        }

        tryCount = 'undefined' === typeof tryCount ? 0 : tryCount;
        var retryLimit = 10;
        var retryTimeout = 10000 * tryCount;
        incrementRatio = parseInt(incrementRatio);

        if (!isNaN(incrementRatio)) {
          retryTimeout *= incrementRatio;
        }

        $.ajax({
          url: ajaxurl + '?action=wpstg_processing&_=' + Date.now() / 1000,
          type: 'POST',
          dataType: dataType,
          cache: false,
          data: data,
          error: function error(xhr, textStatus, errorThrown) {
            console.log(xhr.status + ' ' + xhr.statusText + '---' + textStatus);

            if (typeof errorCallback === 'function') {
              // Custom error handler
              errorCallback(xhr, textStatus, errorThrown);

              if (!WPStagingCommon.continueErrorHandle) {
                // Reset state
                WPStagingCommon.continueErrorHandle = true;
                return;
              }
            } // Default error handler


            tryCount++;

            if (tryCount <= retryLimit) {
              setTimeout(function () {
                WPStagingCommon.ajax(data, callback, dataType, showErrors, tryCount, incrementRatio);
                return;
              }, retryTimeout);
            } else {
              var errorCode = 'undefined' === typeof xhr.status ? 'Unknown' : xhr.status;
              WPStagingCommon.showError('Fatal Error:  ' + errorCode + ' Please try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.');
            }
          },
          success: function success(data) {
            if ('function' === typeof callback) {
              callback(data);
            }
          },
          statusCode: {
            404: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Error 404 - Can\'t find ajax request URL! Please try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.');
              }
            },
            500: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Fatal Error 500 - Internal server error while processing the request! Please try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.');
              }
            },
            504: function _() {
              if (tryCount > retryLimit) {
                WPStagingCommon.showError('Error 504 - It looks like your server is rate limiting ajax requests. Please try to resume after a minute. If this still not works try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.\n\ ');
              }
            },
            502: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Error 502 - It looks like your server is rate limiting ajax requests. Please try to resume after a minute. If this still not works try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.\n\ ');
              }
            },
            503: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Error 503 - It looks like your server is rate limiting ajax requests. Please try to resume after a minute. If this still not works try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.\n\ ');
              }
            },
            429: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Error 429 - It looks like your server is rate limiting ajax requests. Please try to resume after a minute. If this still not works try the <a href=\'https://wp-staging.com/docs/wp-staging-settings-for-small-servers/\' target=\'_blank\'>WP Staging Small Server Settings</a> or submit an error report and contact us.\n\ ');
              }
            },
            403: function _() {
              if (tryCount >= retryLimit) {
                WPStagingCommon.showError('Refresh page or login again! The process should be finished successfully. \n\ ');
              }
            }
          }
        });
      }
    };
    return WPStagingCommon;
  })(jQuery);

  /**
   * WP STAGING basic jQuery replacement
   */

  /**
   * Shortcut for document.querySelector() or jQuery's $()
   * Return single element only
   */

  function qs(selector) {
    return document.querySelector(selector);
  }
  /**
   * alternative of jQuery - $(parent).on(event, selector, handler)
   */

  function addEvent(parent, evt, selector, handler) {
    if (!parent instanceof Element) {
      return;
    }

    parent.addEventListener(evt, function (event) {
      if (event.target.matches(selector + ', ' + selector + ' *')) {
        handler(event.target.closest(selector), event);
      }
    }, false);
  }
  function slideDown(element, duration) {
    if (duration === void 0) {
      duration = 400;
    }

    element.style.display = 'block';
    element.style.overflow = 'hidden';
    var height = element.offsetHeight;
    element.style.height = '0px';
    element.style.transitionProperty = 'height';
    element.style.transitionDuration = duration + 'ms';
    setTimeout(function () {
      element.style.height = height + 'px';
      window.setTimeout(function () {
        element.style.removeProperty('height');
        element.style.removeProperty('overflow');
        element.style.removeProperty('transition-duration');
        element.style.removeProperty('transition-property');
      }, duration);
    }, 0);
  }
  function slideUp(element, duration) {
    if (duration === void 0) {
      duration = 400;
    }

    element.style.display = 'block';
    element.style.overflow = 'hidden';
    var height = element.offsetHeight;
    element.style.height = height + 'px';
    element.style.transitionProperty = 'height';
    element.style.transitionDuration = duration + 'ms';
    setTimeout(function () {
      element.style.height = '0px';
      window.setTimeout(function () {
        element.style.display = 'none';
        element.style.removeProperty('height');
        element.style.removeProperty('overflow');
        element.style.removeProperty('transition-duration');
        element.style.removeProperty('transition-property');
      }, duration);
    }, 0);
  }
  function fadeOut(element, duration) {
    if (duration === void 0) {
      duration = 300;
    }

    element.style.opacity = 1;
    element.style.transitionProperty = 'opacity';
    element.style.transitionDuration = duration + 'ms';
    setTimeout(function () {
      element.style.opacity = 0;
      window.setTimeout(function () {
        element.style.display = 'none';
        element.style.removeProperty('opacity');
        element.style.removeProperty('transition-duration');
        element.style.removeProperty('transition-property');
      }, duration);
    }, 0);
  }
  function getNextSibling(element, selector) {
    var sibling = element.nextElementSibling;

    while (sibling) {
      if (sibling.matches(selector)) {
        return sibling;
      }

      sibling = sibling.nextElementSibling;
    }
  }
  function getParents(element, selector) {
    var result = [];

    for (var parent = element && element.parentElement; parent; parent = parent.parentElement) {
      if (parent.matches(selector)) {
        result.push(parent);
      }
    }

    return result;
  }
  /**
   * A confirmation modal
   *
   * @param title
   * @param html
   * @param confirmText
   * @param confirmButtonClass
   * @return Promise
   */

  function confirmModal(title, html, confirmText, confirmButtonClass) {
    return WPStagingCommon.getSwalModal(false, {
      container: 'wpstg-swal-push-container',
      confirmButton: confirmButtonClass + ' wpstg--btn--confirm wpstg-blue-primary wpstg-button wpstg-link-btn'
    }).fire({
      title: title,
      icon: 'warning',
      html: html,
      width: '750px',
      focusConfirm: false,
      confirmButtonText: confirmText,
      showCancelButton: true
    });
  }

  // This is to make sure we have not many ajax request even when they were not required i.e. while typing.

  var DELAY_TIME_DB_CHECK = 300;

  var WpstgCloneEdit = /*#__PURE__*/function () {
    function WpstgCloneEdit(workflowSelector, dbCheckTriggerClass, wpstgObject, databaseCheckAction) {
      if (workflowSelector === void 0) {
        workflowSelector = '#wpstg-workflow';
      }

      if (dbCheckTriggerClass === void 0) {
        dbCheckTriggerClass = '.wpstg-edit-clone-db-inputs';
      }

      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      if (databaseCheckAction === void 0) {
        databaseCheckAction = 'wpstg_database_connect';
      }

      this.workflow = qs(workflowSelector);
      this.dbCheckTriggerClass = dbCheckTriggerClass;
      this.wpstgObject = wpstgObject;
      this.databaseCheckAction = databaseCheckAction;
      this.dbCheckTimer = null;
      this.abortDbCheckController = null;
      this.dbCheckCallStatus = false;
      this.notyf = new Notyf({
        duration: 10000,
        position: {
          x: 'center',
          y: 'bottom'
        },
        dismissible: true,
        types: [{
          type: 'warning',
          background: 'orange',
          icon: false
        }, {
          type: 'error',
          background: '#e01e5a',
          duration: 2000,
          dismissible: true
        }]
      });
      this.init();
    }

    var _proto = WpstgCloneEdit.prototype;

    _proto.addEvents = function addEvents() {
      var _this = this;

      // early bail if workflow object not available.
      if (this.workflow === null) {
        return;
      }

      ['paste', 'input'].forEach(function (evt) {
        addEvent(_this.workflow, evt, _this.dbCheckTriggerClass, function () {
          // abort previous database check call if it was running
          if (_this.dbCheckCallStatus === true) {
            _this.abortDbCheckController.abort();

            _this.abortDbCheckController = null;
            _this.dbCheckCallStatus = false;
          } // check for db connection after specific delay but reset the timer if these event occur again


          clearTimeout(_this.dbCheckTimer);
          _this.dbCheckTimer = setTimeout(function () {
            _this.checkDatabase();
          }, DELAY_TIME_DB_CHECK);
        });
      });
    };

    _proto.init = function init() {
      this.addEvents();
    };

    _proto.checkDatabase = function checkDatabase() {
      var _this2 = this;

      var idPrefix = '#wpstg-edit-clone-data-';
      var externalDBUser = qs(idPrefix + 'database-user').value;
      var externalDBPassword = qs(idPrefix + 'database-password').value;
      var externalDBDatabase = qs(idPrefix + 'database-database').value;
      var externalDBHost = qs(idPrefix + 'database-server').value;
      var externalDBPrefix = qs(idPrefix + 'database-prefix').value;
      var externalDBSsl = qs(idPrefix + 'database-ssl').checked;

      if (externalDBUser === '' && externalDBPassword === '' && externalDBDatabase === '' && externalDBPrefix === '') {
        qs('#wpstg-save-clone-data').disabled = false;
        return;
      }

      this.abortDbCheckController = new AbortController();
      this.dbCheckCallStatus = true;
      fetch(this.wpstgObject.ajaxUrl, {
        method: 'POST',
        signal: this.abortDbCheckController.signal,
        credentials: 'same-origin',
        body: new URLSearchParams({
          action: this.databaseCheckAction,
          accessToken: this.wpstgObject.accessToken,
          nonce: this.wpstgObject.nonce,
          databaseUser: externalDBUser,
          databasePassword: externalDBPassword,
          databaseServer: externalDBHost,
          databaseDatabase: externalDBDatabase,
          databasePrefix: externalDBPrefix,
          databaseSsl: externalDBSsl,
          databaseEnsurePrefixTableExist: true
        }),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      }).then(function (response) {
        _this2.dbCheckCallStatus = false;

        if (response.ok) {
          return response.json();
        }

        return Promise.reject(response);
      }).then(function (data) {
        // dismiss previous toasts
        _this2.notyf.dismissAll(); // failed request


        if (false === data) {
          _this2.notyf.error(_this2.wpstgObject.i18n['dbConnectionFailed']);

          qs('#wpstg-save-clone-data').disabled = true;
          return;
        } // failed db connection


        if ('undefined' !== typeof data.errors && data.errors && 'undefined' !== typeof data.success && data.success === 'false') {
          _this2.notyf.error(_this2.wpstgObject.i18n['dbConnectionFailed'] + '! <br/> Error: ' + data.errors);

          qs('#wpstg-save-clone-data').disabled = true;
          return;
        } // prefix warning


        if ('undefined' !== typeof data.errors && data.errors && 'undefined' !== typeof data.success && data.success === 'true') {
          _this2.notyf.open({
            type: 'warning',
            message: 'Warning: ' + data.errors
          });

          qs('#wpstg-save-clone-data').disabled = true;
          return;
        } // db connection successful


        if ('undefined' !== typeof data.success && data.success) {
          _this2.notyf.success(_this2.wpstgObject.i18n['dbConnectionSuccess']);

          qs('#wpstg-save-clone-data').disabled = false;
        }
      })["catch"](function (error) {
        _this2.dbCheckCallStatus = false;
        console.warn(_this2.wpstgObject.i18n['somethingWentWrong'], error);
        qs('#wpstg-save-clone-data').disabled = true;
      });
    };

    return WpstgCloneEdit;
  }();

  /**
   * Push Table Selection
   */

  var WpstgPushTableSelection = /*#__PURE__*/function () {
    function WpstgPushTableSelection(workflowSelector, inputSelector, wpstgObject) {
      if (workflowSelector === void 0) {
        workflowSelector = '#wpstg-workflow';
      }

      if (inputSelector === void 0) {
        inputSelector = '#wpstg_select_tables_pushing';
      }

      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      this.workflow = qs(workflowSelector);
      this.inputSelector = inputSelector;
      this.input = qs(inputSelector);
      this.wpstgObject = wpstgObject;
      this.cloneID = this.input.getAttribute('data-clone');
      this.tablePrefix = this.input.getAttribute('data-prefix');
      this.isNetwork = this.input.getAttribute('data-network') === 'true';
      this.areAllTablesChecked = true;
      this.init();
    }

    var _proto = WpstgPushTableSelection.prototype;

    _proto.addEvents = function addEvents() {
      var _this = this;

      addEvent(document.body, 'click', '.wpstg-button-show-tables', function (target) {
        _this.showAllTables();
      });
      addEvent(document.body, 'click', '.wpstg-button-db-prefix', function () {
        _this.selectDefaultTables();
      });
      addEvent(document.body, 'click', '.wpstg-button-unselect', function () {
        _this.toggleTableSelection();
      });
      addEvent(document.body, 'change', this.inputSelector, function () {
        _this.countSelectedTables();
      });
    };

    _proto.init = function init() {
      this.addEvents();
    };

    _proto.showAllTables = function showAllTables() {
      var _this2 = this;

      var includedTables = this.getIncludedTables();
      var excludedTables = this.getExcludedTables();

      if (includedTables.length > excludedTables.length) {
        includedTables = '';
      } else if (excludedTables.length > includedTables.length) {
        excludedTables = '';
      }

      fetch(this.wpstgObject.ajaxUrl, {
        method: 'POST',
        credentials: 'same-origin',
        body: new URLSearchParams({
          action: 'wpstg_push_tables',
          accessToken: this.wpstgObject.accessToken,
          nonce: this.wpstgObject.nonce,
          clone: this.cloneID,
          includedTables: includedTables,
          excludedTables: excludedTables,
          selectedTablesWithoutPrefix: this.getSelectedTablesWithoutPrefix()
        }),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      }).then(function (response) {
        if (response.ok) {
          return response.json();
        }

        return Promise.reject(response);
      }).then(function (data) {
        // Reload current page if successful.
        if ('undefined' !== typeof data.success && data.success) {
          _this2.input.innerHTML = data.content;
          fadeOut(qs('.wpstg-button-show-tables'), 300);

          _this2.countSelectedTables();

          return;
        } // There will be message probably in case of error


        if ('undefined' !== typeof data.message) {
          _this2.notyf.error(data.message);

          return;
        }

        _this2.notyf.error(_this2.wpstgObject.i18n['somethingWentWrong']);
      })["catch"](function (error) {
        console.warn(_this2.wpstgObject.i18n['somethingWentWrong'], error);
      });
    };

    _proto.getRegexPattern = function getRegexPattern() {
      var pattern = '^' + this.tablePrefix;

      if (this.wpstgObject.isMultisite === '1' && !this.isNetwork) {
        pattern += '([^0-9])_*';
      }

      return pattern;
    };

    _proto.selectDefaultTables = function selectDefaultTables() {
      var options = this.input.querySelectorAll('.wpstg-db-table');
      var pattern = this.getRegexPattern();
      options.forEach(function (option) {
        var name = option.getAttribute('name', '');

        if (name.match(pattern)) {
          option.selected = true;
        } else {
          option.selected = false;
        }
      });
      this.countSelectedTables();
    };

    _proto.toggleTableSelection = function toggleTableSelection() {
      if (false === this.areAllTablesChecked) {
        this.input.querySelectorAll('.wpstg-db-table').forEach(function (option) {
          option.selected = true;
        });
        this.workflow.querySelector('.wpstg-button-unselect').innerHTML = 'Unselect All';
        this.areAllTablesChecked = true;
      } else {
        this.input.querySelectorAll('.wpstg-db-table').forEach(function (option) {
          option.selected = false;
        });
        this.workflow.querySelector('.wpstg-button-unselect').innerHTML = 'Select All';
        this.areAllTablesChecked = false;
      }

      this.countSelectedTables();
    };

    _proto.getSelectedTablesWithoutPrefix = function getSelectedTablesWithoutPrefix() {
      var selectedTablesWithoutPrefix = [];
      var regexPattern = this.getRegexPattern();
      this.input.querySelectorAll('option:checked').forEach(function (option) {
        var name = option.getAttribute('name', '');

        if (!name.match(regexPattern)) {
          selectedTablesWithoutPrefix.push(name);
        }
      });
      return selectedTablesWithoutPrefix.join(this.wpstgObject.settings.directorySeparator);
    };

    _proto.getIncludedTables = function getIncludedTables() {
      var tables = [];
      var regexPattern = this.getRegexPattern();
      this.input.querySelectorAll('option:checked').forEach(function (option) {
        var name = option.getAttribute('name', '');

        if (name.match(regexPattern)) {
          tables.push(name);
        }
      });
      return tables.join(this.wpstgObject.settings.directorySeparator);
    };

    _proto.getExcludedTables = function getExcludedTables() {
      var tables = [];
      var regexPattern = this.getRegexPattern();
      this.input.querySelectorAll('option:not(:checked)').forEach(function (option) {
        var name = option.getAttribute('name', '');

        if (name.match(regexPattern)) {
          tables.push(name);
        }
      });
      return tables.join(this.wpstgObject.settings.directorySeparator);
    };

    _proto.countSelectedTables = function countSelectedTables() {
      var tablesCount = this.input.querySelectorAll('option:checked').length;
      var tablesCountElement = qs('#wpstg-tables-count');

      if (tablesCount === 0) {
        tablesCountElement.classList.add('danger');
        tablesCountElement.innerHTML = this.wpstgObject.i18n['noTableSelected'];
      } else {
        tablesCountElement.classList.remove('danger');
        tablesCountElement.innerHTML = this.wpstgObject.i18n['tablesSelected'].replace('{d}', tablesCount);
      }
    };

    return WpstgPushTableSelection;
  }();

  /**
   * Push File Selection
   */

  var WpstgPushFileSelection = /*#__PURE__*/function () {
    function WpstgPushFileSelection(workflowSelector, filesTabSelector, dirSelector, wpstgObject) {
      if (workflowSelector === void 0) {
        workflowSelector = '#wpstg-workflow';
      }

      if (filesTabSelector === void 0) {
        filesTabSelector = '#wpstg-scanning-files';
      }

      if (dirSelector === void 0) {
        dirSelector = '.wpstg-check-dir';
      }

      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      this.workflow = qs(workflowSelector);
      this.filesTabSelector = filesTabSelector;
      this.filesTab = qs(filesTabSelector);
      this.dirSelector = dirSelector;
      this.wpstgObject = wpstgObject;
      this.init();
    }

    var _proto = WpstgPushFileSelection.prototype;

    _proto.addEvents = function addEvents() {
      var _this = this;

      addEvent(this.workflow, 'change', this.filesTabSelector + ' ' + this.dirSelector, function (el) {
        _this.toggleChildren(el);

        _this.countSelectedFiles();
      });
    };

    _proto.init = function init() {
      this.addEvents();
    };

    _proto.toggleChildren = function toggleChildren(el) {
      var parent = getParents(el, '.wpstg-dir')[0];
      var checkboxes = parent.querySelectorAll('.wpstg-subdir>.wpstg-dir>' + this.dirSelector);
      checkboxes.forEach(function (cb) {
        cb.checked = el.checked;
      });
    };

    _proto.countSelectedFiles = function countSelectedFiles() {
      var _this2 = this;

      var filesCount = this.filesTab.querySelectorAll(this.dirSelector + ':checked').length;
      var filesCountElement = qs('#wpstg-files-count');

      if (filesCount === 0) {
        filesCountElement.classList.add('danger');
        filesCountElement.innerHTML = this.wpstgObject.i18n['noFileSelected'];
      } else {
        var themesCount = 0;
        var pluginsCount = 0;
        filesCountElement.classList.remove('danger');
        this.filesTab.querySelectorAll('.wpstg-dir:not(.wpstg-sub-dir)>.wpstg-push-expand-dirs').forEach(function (head) {
          if (head.innerHTML === 'plugins') {
            pluginsCount = head.nextSibling.querySelectorAll(_this2.dirSelector + ':checked').length;
          }

          if (head.innerHTML === 'themes') {
            themesCount = head.nextSibling.querySelectorAll(_this2.dirSelector + ':checked').length;
          }
        });
        filesCountElement.innerHTML = this.wpstgObject.i18n['filesSelected'].replace('{t}', themesCount).replace('{p}', pluginsCount);
      }
    };

    return WpstgPushFileSelection;
  }();

  /**
   * Loader Modal
   */

  var WpstgLoader = /*#__PURE__*/function () {
    function WpstgLoader(wpstgObject) {
      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      this.wpstgObject = wpstgObject;
    }
    /**
     * Show Swal alert with loader and send ajax request to fetch content of alert.
     * @return Promise
     */


    var _proto = WpstgLoader.prototype;

    _proto.showModal = function showModal() {
      var swalPromise = this.loadModal();
      return swalPromise;
    };

    _proto.loadModal = function loadModal() {
      return WPStagingCommon.getSwalModal(false, {
        container: 'wpstg-swal2-container wpstg-swal2-loading wpstg-swal2-loading-sm'
      }).fire({
        title: '',
        icon: 'warning',
        html: this.getAjaxLoader(),
        width: '100px',
        focusConfirm: false,
        showConfirmButton: false,
        showCancelButton: false
      });
    };

    _proto.getAjaxLoader = function getAjaxLoader() {
      return '<div class="wpstg-swal2-ajax-loader"><img src="' + this.wpstgObject.wpstgIcon + '" /></div>';
    };

    return WpstgLoader;
  }();

  var WpstgRemoteStorage = /*#__PURE__*/function () {
    function WpstgRemoteStorage(revokeButtonSelector, revokeProviderFormSelector, revokeAction, settingsButtonSelector, settingsFormSelector, settingsAction, authenticateButtonSelector, authenticateFormSelector, authenticateAction, testConnectionButtonSelector, testConnectionFieldsSelector, testConnectionAction, wpstgObject) {
      if (revokeButtonSelector === void 0) {
        revokeButtonSelector = '#wpstg-btn-provider-revoke';
      }

      if (revokeProviderFormSelector === void 0) {
        revokeProviderFormSelector = '#wpstg-provider-revoke-form';
      }

      if (revokeAction === void 0) {
        revokeAction = 'wpstg-provider-revoke';
      }

      if (settingsButtonSelector === void 0) {
        settingsButtonSelector = '#wpstg-btn-save-provider-settings';
      }

      if (settingsFormSelector === void 0) {
        settingsFormSelector = '#wpstg-provider-settings-form';
      }

      if (settingsAction === void 0) {
        settingsAction = 'wpstg-provider-settings';
      }

      if (authenticateButtonSelector === void 0) {
        authenticateButtonSelector = '#wpstg-btn-provider-authenticate';
      }

      if (authenticateFormSelector === void 0) {
        authenticateFormSelector = '#wpstg-provider-authenticate-form';
      }

      if (authenticateAction === void 0) {
        authenticateAction = 'wpstg-provider-authenticate';
      }

      if (testConnectionButtonSelector === void 0) {
        testConnectionButtonSelector = '#wpstg-btn-provider-test-connection';
      }

      if (testConnectionFieldsSelector === void 0) {
        testConnectionFieldsSelector = '#wpstg-provider-test-connection-fields';
      }

      if (testConnectionAction === void 0) {
        testConnectionAction = 'wpstg-provider-test-connection';
      }

      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      this.revokeButtonSelector = revokeButtonSelector;
      this.revokeForm = qs(revokeProviderFormSelector);
      this.revokeAction = revokeAction;
      this.settingsButtonSelector = settingsButtonSelector;
      this.settingsForm = qs(settingsFormSelector);
      this.settingsAction = settingsAction;
      this.authenticateButtonSelector = authenticateButtonSelector;
      this.authenticateForm = qs(authenticateFormSelector);
      this.authenticateAction = authenticateAction;
      this.testConnectionButtonSelector = testConnectionButtonSelector;
      this.testConnectionFields = qs(testConnectionFieldsSelector);
      this.testConnectionAction = testConnectionAction;
      this.wpstgObject = wpstgObject;
      this.notyf = new Notyf({
        duration: 2000,
        position: {
          x: 'center',
          y: 'bottom'
        },
        dismissible: true,
        types: [{
          type: 'warning',
          background: 'orange',
          icon: false
        }, {
          type: 'error',
          background: '#e01e5a',
          icon: true
        }]
      });
      this.init();
    }

    var _proto = WpstgRemoteStorage.prototype;

    _proto.addEvents = function addEvents() {
      var _this = this;

      addEvent(document.body, 'click', this.revokeButtonSelector, /*#__PURE__*/function () {
        var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(target) {
          return regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) {
              switch (_context.prev = _context.next) {
                case 0:
                  _context.next = 2;
                  return _this.sendRevokeRequest();

                case 2:
                case "end":
                  return _context.stop();
              }
            }
          }, _callee);
        }));

        return function (_x) {
          return _ref.apply(this, arguments);
        };
      }());
      addEvent(document.body, 'click', this.settingsButtonSelector, /*#__PURE__*/function () {
        var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(target) {
          return regeneratorRuntime.wrap(function _callee2$(_context2) {
            while (1) {
              switch (_context2.prev = _context2.next) {
                case 0:
                  _context2.next = 2;
                  return _this.sendSettingsRequest();

                case 2:
                case "end":
                  return _context2.stop();
              }
            }
          }, _callee2);
        }));

        return function (_x2) {
          return _ref2.apply(this, arguments);
        };
      }());
      addEvent(document.body, 'click', this.authenticateButtonSelector, /*#__PURE__*/function () {
        var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(target) {
          return regeneratorRuntime.wrap(function _callee3$(_context3) {
            while (1) {
              switch (_context3.prev = _context3.next) {
                case 0:
                  _context3.next = 2;
                  return _this.sendAuthenticateRequest();

                case 2:
                case "end":
                  return _context3.stop();
              }
            }
          }, _callee3);
        }));

        return function (_x3) {
          return _ref3.apply(this, arguments);
        };
      }());
      addEvent(document.body, 'click', this.testConnectionButtonSelector, /*#__PURE__*/function () {
        var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(target) {
          return regeneratorRuntime.wrap(function _callee4$(_context4) {
            while (1) {
              switch (_context4.prev = _context4.next) {
                case 0:
                  _context4.next = 2;
                  return _this.sendTestConnectionRequest();

                case 2:
                case "end":
                  return _context4.stop();
              }
            }
          }, _callee4);
        }));

        return function (_x4) {
          return _ref4.apply(this, arguments);
        };
      }());
      addEvent(document.body, 'change', '[name=\'ftp_type\']', /*#__PURE__*/function () {
        var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(target) {
          return regeneratorRuntime.wrap(function _callee5$(_context5) {
            while (1) {
              switch (_context5.prev = _context5.next) {
                case 0:
                  _context5.next = 2;
                  return _this.toggleSftpFields();

                case 2:
                case "end":
                  return _context5.stop();
              }
            }
          }, _callee5);
        }));

        return function (_x5) {
          return _ref5.apply(this, arguments);
        };
      }());
      addEvent(document.body, 'change', '[name=\'s3_provider\']', /*#__PURE__*/function () {
        var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(target) {
          return regeneratorRuntime.wrap(function _callee6$(_context6) {
            while (1) {
              switch (_context6.prev = _context6.next) {
                case 0:
                  _context6.next = 2;
                  return _this.toggleS3GenericFields();

                case 2:
                case "end":
                  return _context6.stop();
              }
            }
          }, _callee6);
        }));

        return function (_x6) {
          return _ref6.apply(this, arguments);
        };
      }());
    };

    _proto.init = function init() {
      this.addEvents();
    };

    _proto.sendRevokeRequest = /*#__PURE__*/function () {
      var _sendRevokeRequest = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7() {
        var provider, response, data;
        return regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) {
            switch (_context7.prev = _context7.next) {
              case 0:
                provider = this.revokeForm.querySelector('input[name="provider"]').value;
                _context7.prev = 1;
                _context7.next = 4;
                return fetch(this.wpstgObject.ajaxUrl, {
                  method: 'POST',
                  credentials: 'same-origin',
                  body: new URLSearchParams({
                    action: this.revokeAction,
                    accessToken: this.wpstgObject.accessToken,
                    nonce: this.wpstgObject.nonce,
                    provider: provider
                  }),
                  headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                  }
                });

              case 4:
                response = _context7.sent;

                if (!response.ok) {
                  console.error("An error has occured: " + response.status);
                }

                _context7.next = 8;
                return response.json();

              case 8:
                data = _context7.sent;

                if (!data.success) {
                  _context7.next = 13;
                  break;
                }

                this.notyf.success(data.message);
                setTimeout(function () {
                  window.location.reload();
                }, 3000);
                return _context7.abrupt("return");

              case 13:
                this.notyf.error(data.message);
                _context7.next = 19;
                break;

              case 16:
                _context7.prev = 16;
                _context7.t0 = _context7["catch"](1);
                console.warn(_context7.t0);

              case 19:
              case "end":
                return _context7.stop();
            }
          }
        }, _callee7, this, [[1, 16]]);
      }));

      function sendRevokeRequest() {
        return _sendRevokeRequest.apply(this, arguments);
      }

      return sendRevokeRequest;
    }();

    _proto.sendSettingsRequest = /*#__PURE__*/function () {
      var _sendSettingsRequest = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8() {
        var loader, swal, formData, queryString, response, data;
        return regeneratorRuntime.wrap(function _callee8$(_context8) {
          while (1) {
            switch (_context8.prev = _context8.next) {
              case 0:
                loader = new WpstgLoader();
                swal = loader.showModal();
                formData = new FormData(this.settingsForm);
                formData.append('action', this.settingsAction);
                formData.append('accessToken', this.wpstgObject.accessToken);
                formData.append('nonce', this.wpstgObject.nonce);
                queryString = new URLSearchParams(formData);
                _context8.prev = 7;
                _context8.next = 10;
                return fetch(this.wpstgObject.ajaxUrl, {
                  method: 'POST',
                  credentials: 'same-origin',
                  body: queryString,
                  headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                  }
                });

              case 10:
                response = _context8.sent;

                if (!response.ok) {
                  console.error("An error has occured: " + response.status);
                }

                _context8.next = 14;
                return response.json();

              case 14:
                data = _context8.sent;

                if (!data.success) {
                  this.notyf.error(data.message);
                }

                if (data.warning) {
                  this.notyf.open({
                    type: 'warning',
                    message: data.message
                  });
                } else {
                  this.notyf.success(data.message);
                }

                setTimeout(function () {
                  window.location.reload();
                }, 2000);
                _context8.next = 23;
                break;

              case 20:
                _context8.prev = 20;
                _context8.t0 = _context8["catch"](7);
                console.warn(_context8.t0);

              case 23:
                _context8.prev = 23;
                swal.close();
                return _context8.finish(23);

              case 26:
              case "end":
                return _context8.stop();
            }
          }
        }, _callee8, this, [[7, 20, 23, 26]]);
      }));

      function sendSettingsRequest() {
        return _sendSettingsRequest.apply(this, arguments);
      }

      return sendSettingsRequest;
    }();

    _proto.sendAuthenticateRequest = /*#__PURE__*/function () {
      var _sendAuthenticateRequest = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9() {
        var formData, queryString, response, data;
        return regeneratorRuntime.wrap(function _callee9$(_context9) {
          while (1) {
            switch (_context9.prev = _context9.next) {
              case 0:
                formData = new FormData(this.authenticateForm);
                formData.append('action', this.authenticateAction);
                formData.append('accessToken', this.wpstgObject.accessToken);
                formData.append('nonce', this.wpstgObject.nonce);
                queryString = new URLSearchParams(formData);
                _context9.prev = 5;
                _context9.next = 8;
                return fetch(this.wpstgObject.ajaxUrl, {
                  method: 'POST',
                  credentials: 'same-origin',
                  body: queryString,
                  headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                  }
                });

              case 8:
                response = _context9.sent;

                if (!response.ok) {
                  console.error("An error has occured: " + response.status);
                }

                _context9.next = 12;
                return response.json();

              case 12:
                data = _context9.sent;

                if (!data.success) {
                  _context9.next = 17;
                  break;
                }

                this.notyf.success(data.message);
                setTimeout(function () {
                  window.location.reload();
                }, 2000);
                return _context9.abrupt("return");

              case 17:
                this.notyf.error(data.message);
                _context9.next = 23;
                break;

              case 20:
                _context9.prev = 20;
                _context9.t0 = _context9["catch"](5);
                console.warn(_context9.t0);

              case 23:
              case "end":
                return _context9.stop();
            }
          }
        }, _callee9, this, [[5, 20]]);
      }));

      function sendAuthenticateRequest() {
        return _sendAuthenticateRequest.apply(this, arguments);
      }

      return sendAuthenticateRequest;
    }();

    _proto.sendTestConnectionRequest = /*#__PURE__*/function () {
      var _sendTestConnectionRequest = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10() {
        var loader, swal, fields, formData, queryString, response, data;
        return regeneratorRuntime.wrap(function _callee10$(_context10) {
          while (1) {
            switch (_context10.prev = _context10.next) {
              case 0:
                loader = new WpstgLoader();
                swal = loader.showModal();
                fields = this.testConnectionFields.querySelectorAll('[name]');
                formData = new FormData();
                formData.append('action', this.testConnectionAction);
                formData.append('accessToken', this.wpstgObject.accessToken);
                formData.append('nonce', this.wpstgObject.nonce);
                fields.forEach(function (element) {
                  console.log(element);

                  if (element.type === 'check' || element.type === 'checkbox') {
                    formData.append(element.getAttribute('name'), element.checked);
                    return;
                  }

                  formData.append(element.getAttribute('name'), element.value);
                });
                queryString = new URLSearchParams(formData);
                _context10.prev = 9;
                _context10.next = 12;
                return fetch(this.wpstgObject.ajaxUrl, {
                  method: 'POST',
                  credentials: 'same-origin',
                  body: queryString,
                  headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                  }
                });

              case 12:
                response = _context10.sent;

                if (!response.ok) {
                  console.error("An error has occured: " + response.status);
                }

                _context10.next = 16;
                return response.json();

              case 16:
                data = _context10.sent;

                if (!data.success) {
                  _context10.next = 20;
                  break;
                }

                this.notyf.success(data.message);
                return _context10.abrupt("return");

              case 20:
                this.notyf.error(data.message);
                _context10.next = 26;
                break;

              case 23:
                _context10.prev = 23;
                _context10.t0 = _context10["catch"](9);
                console.warn(_context10.t0);

              case 26:
                _context10.prev = 26;
                swal.close();
                return _context10.finish(26);

              case 29:
              case "end":
                return _context10.stop();
            }
          }
        }, _callee10, this, [[9, 23, 26, 29]]);
      }));

      function sendTestConnectionRequest() {
        return _sendTestConnectionRequest.apply(this, arguments);
      }

      return sendTestConnectionRequest;
    }();

    _proto.toggleSftpFields = function toggleSftpFields() {
      var ftpType = document.querySelector('[name=\'ftp_type\']');
      var sftpElements = document.querySelectorAll('.only-sftp');
      var ftpElements = document.querySelectorAll('.only-ftp');

      if (ftpType.value === 'ftp') {
        if (sftpElements.length) {
          for (var _iterator = _createForOfIteratorHelperLoose(sftpElements), _step; !(_step = _iterator()).done;) {
            var el = _step.value;
            el.classList.add('hidden');
          }
        }

        if (ftpElements.length) {
          for (var _iterator2 = _createForOfIteratorHelperLoose(ftpElements), _step2; !(_step2 = _iterator2()).done;) {
            var _el = _step2.value;

            _el.classList.remove('hidden');
          }
        }

        return;
      }

      if (sftpElements.length) {
        for (var _iterator3 = _createForOfIteratorHelperLoose(sftpElements), _step3; !(_step3 = _iterator3()).done;) {
          var _el2 = _step3.value;

          _el2.classList.remove('hidden');
        }
      }

      if (ftpElements.length) {
        for (var _iterator4 = _createForOfIteratorHelperLoose(ftpElements), _step4; !(_step4 = _iterator4()).done;) {
          var _el3 = _step4.value;

          _el3.classList.add('hidden');
        }
      }
    };

    _proto.toggleS3GenericFields = function toggleS3GenericFields() {
      var s3Provider = document.querySelector('[name=\'s3_provider\']');
      var isCustomProvider = s3Provider.value === '';
      var customFieldsContainer = document.getElementById('wpstg-s3-custom-provider-fields');
      customFieldsContainer.style.display = isCustomProvider ? 'block' : 'none';
    };

    return WpstgRemoteStorage;
  }();

  /**
   * Fetch directory direct child directories
   */

  var WpstgDirectoryNavigation = /*#__PURE__*/function () {
    function WpstgDirectoryNavigation(directoryListingSelector, workflowSelector, wpstgObject, notyf) {
      if (directoryListingSelector === void 0) {
        directoryListingSelector = '#wpstg-directories-listing';
      }

      if (workflowSelector === void 0) {
        workflowSelector = '#wpstg-workflow';
      }

      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      if (notyf === void 0) {
        notyf = null;
      }

      this.directoryListingContainer = qs(directoryListingSelector);
      this.workflow = qs(workflowSelector);
      this.wpstgObject = wpstgObject;
      this.dirCheckboxSelector = '.wpstg-check-dir';
      this.dirExpandSelector = '.wpstg-expand-dirs';
      this.unselectAllDirsSelector = '.wpstg-unselect-dirs';
      this.selectDefaultDirsSelector = '.wpstg-select-dirs-default';
      this.fetchChildrenAction = 'wpstg_fetch_dir_children';
      this.currentCheckboxElement = null;
      this.currentParentDiv = null;
      this.currentLoader = null;
      this.existingExcludes = [];
      this.excludedDirectories = [];
      this.isDefaultSelected = false;
      this.notyf = notyf;
      this.init();
    }

    var _proto = WpstgDirectoryNavigation.prototype;

    _proto.addEvents = function addEvents() {
      var _this = this;

      if (this.directoryListingContainer === null) {
        console.log('Error: directory navigation add events');
        return;
      }

      addEvent(this.directoryListingContainer, 'change', this.dirCheckboxSelector, function (element, event) {
        event.preventDefault();
      });
      addEvent(this.directoryListingContainer, 'click', this.dirExpandSelector, function (element, event) {
        event.preventDefault();

        if (_this.toggleDirExpand(element)) {
          _this.sendRequest(_this.fetchChildrenAction, element);
        }
      });
      addEvent(this.directoryListingContainer, 'click', this.unselectAllDirsSelector, function () {
        _this.unselectAll();
      });
      addEvent(this.directoryListingContainer, 'click', this.selectDefaultDirsSelector, function () {
        _this.selectDefault();
      });
      addEvent(this.directoryListingContainer, 'click', '.wpstg-expand-dirs', function (target, event) {
        event.preventDefault();

        _this.toggleDirectoryNavigation(target);
      });
      addEvent(this.directoryListingContainer, 'change', 'input.wpstg-check-dir', function (target) {
        _this.updateDirectorySelection(target);
      });
    };

    _proto.init = function init() {
      this.addEvents();
      this.parseExcludes();
    }
    /**
     * Toggle Dir Expand,
     * Return true if children aren't fetched
     * @param {HTMLElement} element
     * @return {boolean}
     */
    ;

    _proto.toggleDirExpand = function toggleDirExpand(element) {
      this.currentParentDiv = element.parentElement;
      this.currentCheckboxElement = element.previousSibling;
      this.currentLoader = this.currentParentDiv.querySelector('.wpstg-is-dir-loading');

      if (this.currentCheckboxElement.getAttribute('data-navigateable', 'false') === 'false') {
        return false;
      }

      if (this.currentCheckboxElement.getAttribute('data-scanned', 'false') === 'false') {
        return true;
      }

      return false;
    };

    _proto.sendRequest = function sendRequest(action) {
      var _this2 = this;

      if (this.currentLoader !== null) {
        this.currentLoader.style.display = 'inline-block';
      }

      var changed = this.currentCheckboxElement.getAttribute('data-changed');
      fetch(this.wpstgObject.ajaxUrl, {
        method: 'POST',
        credentials: 'same-origin',
        body: new URLSearchParams({
          action: action,
          accessToken: this.wpstgObject.accessToken,
          nonce: this.wpstgObject.nonce,
          dirPath: this.currentCheckboxElement.value,
          isChecked: this.currentCheckboxElement.checked,
          forceDefault: changed === 'true'
        }),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      }).then(function (response) {
        if (response.ok) {
          return response.json();
        }

        return Promise.reject(response);
      }).then(function (data) {
        if ('undefined' !== typeof data.success && data.success) {
          _this2.currentCheckboxElement.setAttribute('data-scanned', true);

          var dirContainer = document.createElement('div');
          dirContainer.classList.add('wpstg-dir');
          dirContainer.classList.add('wpstg-subdir');
          dirContainer.innerHTML = JSON.parse(data.directoryListing);

          _this2.currentParentDiv.appendChild(dirContainer);

          if (_this2.currentLoader !== null) {
            _this2.currentLoader.style.display = 'none';
          }

          slideDown(dirContainer);
          return;
        }

        if (_this2.notyf !== null) {
          _this2.notyf.error(_this2.wpstgObject.i18n['somethingWentWrong']);
        } else {
          alert('Error: ' + _this2.wpstgObject.i18n['somethingWentWrong']);
        }
      })["catch"](function (error) {
        console.warn(_this2.wpstgObject.i18n['somethingWentWrong'], error);
      });
    };

    _proto.getExcludedDirectories = function getExcludedDirectories() {
      var _this3 = this;

      this.excludedDirectories = [];
      this.directoryListingContainer.querySelectorAll('.wpstg-dir input:not(:checked)').forEach(function (element) {
        if (!_this3.isParentExcluded(element.value)) {
          _this3.excludedDirectories.push(element.value);
        }
      });

      if (!this.existingExcludes) {
        this.existingExcludes = [];
      }

      this.existingExcludes.forEach(function (exclude) {
        if (!_this3.isParentExcluded(exclude) && !_this3.isScanned(exclude)) {
          _this3.excludedDirectories.push(exclude);
        }
      });
      return this.excludedDirectories.join(this.wpstgObject.settings.directorySeparator);
    }
    /**
     * @param {string} path
     * @return {bool}
     */
    ;

    _proto.isParentExcluded = function isParentExcluded(path) {
      var isParentAlreadyExcluded = false;
      this.excludedDirectories.forEach(function (dir) {
        if (path.startsWith(dir + '/')) {
          isParentAlreadyExcluded = true;
        }
      });
      return isParentAlreadyExcluded;
    };

    _proto.getExtraDirectoriesRootOnly = function getExtraDirectoriesRootOnly() {
      this.getExcludedDirectories();
      var extraDirectories = [];
      this.directoryListingContainer.querySelectorAll(':not(.wpstg-subdir)>.wpstg-dir>input.wpstg-wp-non-core-dir:checked').forEach(function (element) {
        extraDirectories.push(element.value);
      }); // Check if extra directories text area exists
      // TODO: remove extraCustomDirectories code if no one require extraCustomDirectories...

      var extraDirectoriesTextArea = qs('#wpstg_extraDirectories');

      if (extraDirectoriesTextArea === null || extraDirectoriesTextArea.value === '') {
        return extraDirectories.join(this.wpstgObject.settings.directorySeparator);
      }

      var extraCustomDirectories = extraDirectoriesTextArea.value.split(/\r?\n/);
      return extraDirectories.concat(extraCustomDirectories).join(this.wpstgObject.settings.directorySeparator);
    };

    _proto.unselectAll = function unselectAll() {
      this.directoryListingContainer.querySelectorAll('.wpstg-dir input').forEach(function (element) {
        element.checked = false;
      });
      this.countSelectedFiles();
    };

    _proto.selectDefault = function selectDefault() {
      // unselect all checkboxes
      this.unselectAll(); // only select those checkboxes whose class is wpstg-wp-core-dir

      this.directoryListingContainer.querySelectorAll('.wpstg-dir input.wpstg-wp-core-dir').forEach(function (element) {
        element.checked = true;
      }); // then unselect those checkboxes whose parent has wpstg extra checkbox

      this.directoryListingContainer.querySelectorAll('.wpstg-dir > .wpstg-wp-non-core-dir').forEach(function (element) {
        element.parentElement.querySelectorAll('input.wpstg-wp-core-dir').forEach(function (element) {
          element.checked = false;
        });
      });
      this.isDefaultSelected = true;
      this.countSelectedFiles();
    };

    _proto.parseExcludes = function parseExcludes() {
      this.existingExcludes = this.directoryListingContainer.getAttribute('data-existing-excludes', []);

      if (typeof this.existingExcludes === 'undefined' || !this.existingExcludes) {
        this.existingExcludes = [];
        return;
      }

      if (this.existingExcludes.length === 0) {
        this.existingExcludes = [];
        return;
      }

      var existingExcludes = this.existingExcludes.split(',');
      this.existingExcludes = existingExcludes.map(function (exclude) {
        if (exclude.substr(0, 1) === '/') {
          return exclude.slice(1);
        }

        return exclude;
      });
    };

    _proto.isScanned = function isScanned(exclude) {
      var scanned = false;
      this.directoryListingContainer.querySelectorAll('.wpstg-dir>input').forEach(function (element) {
        if (element.value == exclude) {
          scanned = true;
        }
      });
      return scanned;
    };

    _proto.toggleDirectoryNavigation = function toggleDirectoryNavigation(element) {
      var cbElement = element.previousSibling;

      if (cbElement.getAttribute('data-navigateable', 'false') === 'false') {
        return;
      }

      if (cbElement.getAttribute('data-scanned', 'false') === 'false') {
        return;
      }

      var subDirectories = getNextSibling(element, '.wpstg-subdir');

      if (subDirectories.style.display === 'none') {
        slideDown(subDirectories);
      } else {
        slideUp(subDirectories);
      }
    };

    _proto.updateDirectorySelection = function updateDirectorySelection(element) {
      var parent = element.parentElement;
      element.setAttribute('data-changed', 'true');

      if (element.checked) {
        getParents(parent, '.wpstg-dir').forEach(function (parElem) {
          for (var i = 0; i < parElem.children.length; i++) {
            if (parElem.children[i].matches('.wpstg-check-dir')) {
              parElem.children[i].checked = true;
            }
          }
        });
        parent.querySelectorAll('.wpstg-expand-dirs').forEach(function (x) {
          if (x.textContent === 'wp-admin' || x.textContent === 'wp-includes') {
            return;
          }

          x.classList.remove('disabled');
        });
        parent.querySelectorAll('.wpstg-subdir .wpstg-check-dir').forEach(function (x) {
          x.checked = true;
        });
      } else {
        parent.querySelectorAll('.wpstg-expand-dirs, .wpstg-check-subdirs').forEach(function (x) {
          x.classList.add('disabled');
        });
        parent.querySelectorAll('.wpstg-dir .wpstg-check-dir').forEach(function (x) {
          x.checked = false;
        });
      }

      this.countSelectedFiles();
    };

    _proto.countSelectedFiles = function countSelectedFiles() {
      var themesCount = this.directoryListingContainer.querySelectorAll('[data-content-type="theme"]:checked').length;
      var pluginsCount = this.directoryListingContainer.querySelectorAll('[data-content-type="plugin"]:checked').length;
      var filesCountElement = qs('#wpstg-files-count');

      if (themesCount === 0 && pluginsCount === 0) {
        filesCountElement.classList.add('danger');
        filesCountElement.innerHTML = this.wpstgObject.i18n['noFileSelected'];
      } else {
        filesCountElement.classList.remove('danger');
        filesCountElement.innerHTML = this.wpstgObject.i18n['filesSelected'].replace('{t}', themesCount).replace('{p}', pluginsCount);
      }
    };

    return WpstgDirectoryNavigation;
  }();

  var WpstgCloneGenerateLoginLink = /*#__PURE__*/function () {
    function WpstgCloneGenerateLoginLink() {
      this.generateLoginLink();
    }

    var _proto = WpstgCloneGenerateLoginLink.prototype;

    _proto.generateLoginLink = function generateLoginLink() {
      var notyfG = new Notyf({
        duration: 4000,
        position: {
          x: 'center',
          y: 'bottom'
        },
        dismissible: true
      });
      addEvent(document.body, 'click', '.wpstg-generate-login-link-action', function (element) {
        WPStaging.ajax({
          action: 'wpstg_render_login_link_user_interface',
          clone: element.getAttribute('data-clone'),
          cloneName: element.getAttribute('data-name'),
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce
        }, function (response) {
          qs('#wpstg-workflow').innerHTML = response;
        }, 'HTML');
      });
      addEvent(document.body, 'click', '#wpstg-generate-login-link', function (element) {
        var html = '<p class=\'wpstg-push-confirmation-message\'> ' + element.getAttribute('data-alert-body') + '</p>';
        confirmModal(element.getAttribute('data-alert-title'), html, element.getAttribute('data-confirm-btn-text'), 'wpstg-confirm-link-save').then(function (result) {
          if (result.value) {
            var idPrefix = '#wpstg-generate-login-link-';
            var cloneID = qs(idPrefix + 'clone-id').value;
            var role = qs(idPrefix + 'role').value;
            var minutes = qs(idPrefix + 'minutes').value;
            var hours = qs(idPrefix + 'hours').value;
            var days = qs(idPrefix + 'days').value;
            var url = qs(idPrefix + 'generated').getAttribute('data-url');
            var uniqueid = Date.now().toString();
            WPStaging.ajax({
              action: 'wpstg_save_generated_link_data',
              accessToken: wpstg.accessToken,
              nonce: wpstg.nonce,
              cloneID: cloneID,
              role: role,
              minutes: minutes,
              hours: hours,
              days: days,
              uniqueid: uniqueid
            }, function (response) {
              if (response.success) {
                qs('#wpstg-generate-login-link-head').style.display = '';
                qs('#wpstg-generate-login-link-generated').innerText = url + uniqueid;
                notyfG.success(response.data.message);
              } else {
                notyfG.error(response.data.message);
              }

              return;
            }, 'json');
          }
        });
      });
      addEvent(document.body, 'mouseover', '#wpstg-generate-login-link-generated', function (e) {
        qs('#wpstg-generate-login-link-copy-text').innerText = qs('#wpstg-generate-login-link-copy-text').getAttribute('data-copy');
        qs('#wpstg-generate-login-link-copy-text').style.display = '';
      });
      addEvent(document.body, 'mouseleave', '#wpstg-generate-login-link-generated', function (e) {
        qs('#wpstg-generate-login-link-copy-text').style.display = 'none';
      });
      addEvent(document.body, 'click', '#wpstg-generate-login-link-generated', function (element) {
        navigator.clipboard.writeText(element.innerHTML);
        qs('#wpstg-generate-login-link-copy-text').innerText = qs('#wpstg-generate-login-link-copy-text').getAttribute('data-copied');
      });
    };

    return WpstgCloneGenerateLoginLink;
  }();

  var WpstgSyncAccount = /*#__PURE__*/function () {
    function WpstgSyncAccount() {
      this.syncAccount();
    }

    var _proto = WpstgSyncAccount.prototype;

    _proto.syncAccount = function syncAccount() {
      var $that = this;
      addEvent(document.body, 'click', '.wpstg-sync-account', function (e) {
        var $this = qs('.wpstg-sync-account');
        var dataset = $this.dataset;
        var html = '<p class=\'wpstg-push-confirmation-message\'> ' + dataset.alertBody + '</p>';
        $that.confirmModal(dataset.alertTitle, html, dataset.confirmBtnText, 'wpstg-confirm-sync-account').then(function (result) {
          var cloneID = dataset.clone;

          if (result.value) {
            WPStaging.ajax({
              action: 'wpstg_sync_account',
              accessToken: wpstg.accessToken,
              nonce: wpstg.nonce,
              clone: cloneID
            }, function (response) {
              if (response.data.message) {
                if (response.success) {
                  WPStagingCommon.showSuccessModal(response.data.message);
                } else {
                  WPStagingCommon.showErrorModal(response.data.message);
                }
              }
            }, 'json', false);
            return;
          }
        });
      });
    };

    /**
     * A confirmation modal
     *
     * @param html
     * @param confirmText
     * @param confirmButtonClass
     * @return Promise
     */
    _proto.confirmModal = function confirmModal(title, html, confirmText, confirmButtonClass) {
      return WPStagingCommon.getSwalModal(false, {
        container: 'wpstg-swal-push-container',
        confirmButton: confirmButtonClass + ' wpstg--btn--confirm wpstg-blue-primary wpstg-button wpstg-link-btn'
      }).fire({
        title: title,
        icon: 'warning',
        html: html,
        width: '750px',
        focusConfirm: false,
        confirmButtonText: confirmText,
        showCancelButton: true
      });
    };

    return WpstgSyncAccount;
  }();

  /**
   * Copyright (c) 2014-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var runtime = (function (exports) {

    var Op = Object.prototype;
    var hasOwn = Op.hasOwnProperty;
    var undefined$1; // More compressible than void 0.
    var $Symbol = typeof Symbol === "function" ? Symbol : {};
    var iteratorSymbol = $Symbol.iterator || "@@iterator";
    var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
    var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

    function define(obj, key, value) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
      return obj[key];
    }
    try {
      // IE 8 has a broken Object.defineProperty that only works on DOM objects.
      define({}, "");
    } catch (err) {
      define = function(obj, key, value) {
        return obj[key] = value;
      };
    }

    function wrap(innerFn, outerFn, self, tryLocsList) {
      // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
      var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
      var generator = Object.create(protoGenerator.prototype);
      var context = new Context(tryLocsList || []);

      // The ._invoke method unifies the implementations of the .next,
      // .throw, and .return methods.
      generator._invoke = makeInvokeMethod(innerFn, self, context);

      return generator;
    }
    exports.wrap = wrap;

    // Try/catch helper to minimize deoptimizations. Returns a completion
    // record like context.tryEntries[i].completion. This interface could
    // have been (and was previously) designed to take a closure to be
    // invoked without arguments, but in all the cases we care about we
    // already have an existing method we want to call, so there's no need
    // to create a new function object. We can even get away with assuming
    // the method takes exactly one argument, since that happens to be true
    // in every case, so we don't have to touch the arguments object. The
    // only additional allocation required is the completion record, which
    // has a stable shape and so hopefully should be cheap to allocate.
    function tryCatch(fn, obj, arg) {
      try {
        return { type: "normal", arg: fn.call(obj, arg) };
      } catch (err) {
        return { type: "throw", arg: err };
      }
    }

    var GenStateSuspendedStart = "suspendedStart";
    var GenStateSuspendedYield = "suspendedYield";
    var GenStateExecuting = "executing";
    var GenStateCompleted = "completed";

    // Returning this object from the innerFn has the same effect as
    // breaking out of the dispatch switch statement.
    var ContinueSentinel = {};

    // Dummy constructor functions that we use as the .constructor and
    // .constructor.prototype properties for functions that return Generator
    // objects. For full spec compliance, you may wish to configure your
    // minifier not to mangle the names of these two functions.
    function Generator() {}
    function GeneratorFunction() {}
    function GeneratorFunctionPrototype() {}

    // This is a polyfill for %IteratorPrototype% for environments that
    // don't natively support it.
    var IteratorPrototype = {};
    IteratorPrototype[iteratorSymbol] = function () {
      return this;
    };

    var getProto = Object.getPrototypeOf;
    var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
    if (NativeIteratorPrototype &&
        NativeIteratorPrototype !== Op &&
        hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
      // This environment has a native %IteratorPrototype%; use it instead
      // of the polyfill.
      IteratorPrototype = NativeIteratorPrototype;
    }

    var Gp = GeneratorFunctionPrototype.prototype =
      Generator.prototype = Object.create(IteratorPrototype);
    GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
    GeneratorFunctionPrototype.constructor = GeneratorFunction;
    GeneratorFunction.displayName = define(
      GeneratorFunctionPrototype,
      toStringTagSymbol,
      "GeneratorFunction"
    );

    // Helper for defining the .next, .throw, and .return methods of the
    // Iterator interface in terms of a single ._invoke method.
    function defineIteratorMethods(prototype) {
      ["next", "throw", "return"].forEach(function(method) {
        define(prototype, method, function(arg) {
          return this._invoke(method, arg);
        });
      });
    }

    exports.isGeneratorFunction = function(genFun) {
      var ctor = typeof genFun === "function" && genFun.constructor;
      return ctor
        ? ctor === GeneratorFunction ||
          // For the native GeneratorFunction constructor, the best we can
          // do is to check its .name property.
          (ctor.displayName || ctor.name) === "GeneratorFunction"
        : false;
    };

    exports.mark = function(genFun) {
      if (Object.setPrototypeOf) {
        Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
      } else {
        genFun.__proto__ = GeneratorFunctionPrototype;
        define(genFun, toStringTagSymbol, "GeneratorFunction");
      }
      genFun.prototype = Object.create(Gp);
      return genFun;
    };

    // Within the body of any async function, `await x` is transformed to
    // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
    // `hasOwn.call(value, "__await")` to determine if the yielded value is
    // meant to be awaited.
    exports.awrap = function(arg) {
      return { __await: arg };
    };

    function AsyncIterator(generator, PromiseImpl) {
      function invoke(method, arg, resolve, reject) {
        var record = tryCatch(generator[method], generator, arg);
        if (record.type === "throw") {
          reject(record.arg);
        } else {
          var result = record.arg;
          var value = result.value;
          if (value &&
              typeof value === "object" &&
              hasOwn.call(value, "__await")) {
            return PromiseImpl.resolve(value.__await).then(function(value) {
              invoke("next", value, resolve, reject);
            }, function(err) {
              invoke("throw", err, resolve, reject);
            });
          }

          return PromiseImpl.resolve(value).then(function(unwrapped) {
            // When a yielded Promise is resolved, its final value becomes
            // the .value of the Promise<{value,done}> result for the
            // current iteration.
            result.value = unwrapped;
            resolve(result);
          }, function(error) {
            // If a rejected Promise was yielded, throw the rejection back
            // into the async generator function so it can be handled there.
            return invoke("throw", error, resolve, reject);
          });
        }
      }

      var previousPromise;

      function enqueue(method, arg) {
        function callInvokeWithMethodAndArg() {
          return new PromiseImpl(function(resolve, reject) {
            invoke(method, arg, resolve, reject);
          });
        }

        return previousPromise =
          // If enqueue has been called before, then we want to wait until
          // all previous Promises have been resolved before calling invoke,
          // so that results are always delivered in the correct order. If
          // enqueue has not been called before, then it is important to
          // call invoke immediately, without waiting on a callback to fire,
          // so that the async generator function has the opportunity to do
          // any necessary setup in a predictable way. This predictability
          // is why the Promise constructor synchronously invokes its
          // executor callback, and why async functions synchronously
          // execute code before the first await. Since we implement simple
          // async functions in terms of async generators, it is especially
          // important to get this right, even though it requires care.
          previousPromise ? previousPromise.then(
            callInvokeWithMethodAndArg,
            // Avoid propagating failures to Promises returned by later
            // invocations of the iterator.
            callInvokeWithMethodAndArg
          ) : callInvokeWithMethodAndArg();
      }

      // Define the unified helper method that is used to implement .next,
      // .throw, and .return (see defineIteratorMethods).
      this._invoke = enqueue;
    }

    defineIteratorMethods(AsyncIterator.prototype);
    AsyncIterator.prototype[asyncIteratorSymbol] = function () {
      return this;
    };
    exports.AsyncIterator = AsyncIterator;

    // Note that simple async functions are implemented on top of
    // AsyncIterator objects; they just return a Promise for the value of
    // the final result produced by the iterator.
    exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
      if (PromiseImpl === void 0) PromiseImpl = Promise;

      var iter = new AsyncIterator(
        wrap(innerFn, outerFn, self, tryLocsList),
        PromiseImpl
      );

      return exports.isGeneratorFunction(outerFn)
        ? iter // If outerFn is a generator, return the full iterator.
        : iter.next().then(function(result) {
            return result.done ? result.value : iter.next();
          });
    };

    function makeInvokeMethod(innerFn, self, context) {
      var state = GenStateSuspendedStart;

      return function invoke(method, arg) {
        if (state === GenStateExecuting) {
          throw new Error("Generator is already running");
        }

        if (state === GenStateCompleted) {
          if (method === "throw") {
            throw arg;
          }

          // Be forgiving, per 25.3.3.3.3 of the spec:
          // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
          return doneResult();
        }

        context.method = method;
        context.arg = arg;

        while (true) {
          var delegate = context.delegate;
          if (delegate) {
            var delegateResult = maybeInvokeDelegate(delegate, context);
            if (delegateResult) {
              if (delegateResult === ContinueSentinel) continue;
              return delegateResult;
            }
          }

          if (context.method === "next") {
            // Setting context._sent for legacy support of Babel's
            // function.sent implementation.
            context.sent = context._sent = context.arg;

          } else if (context.method === "throw") {
            if (state === GenStateSuspendedStart) {
              state = GenStateCompleted;
              throw context.arg;
            }

            context.dispatchException(context.arg);

          } else if (context.method === "return") {
            context.abrupt("return", context.arg);
          }

          state = GenStateExecuting;

          var record = tryCatch(innerFn, self, context);
          if (record.type === "normal") {
            // If an exception is thrown from innerFn, we leave state ===
            // GenStateExecuting and loop back for another invocation.
            state = context.done
              ? GenStateCompleted
              : GenStateSuspendedYield;

            if (record.arg === ContinueSentinel) {
              continue;
            }

            return {
              value: record.arg,
              done: context.done
            };

          } else if (record.type === "throw") {
            state = GenStateCompleted;
            // Dispatch the exception by looping back around to the
            // context.dispatchException(context.arg) call above.
            context.method = "throw";
            context.arg = record.arg;
          }
        }
      };
    }

    // Call delegate.iterator[context.method](context.arg) and handle the
    // result, either by returning a { value, done } result from the
    // delegate iterator, or by modifying context.method and context.arg,
    // setting context.delegate to null, and returning the ContinueSentinel.
    function maybeInvokeDelegate(delegate, context) {
      var method = delegate.iterator[context.method];
      if (method === undefined$1) {
        // A .throw or .return when the delegate iterator has no .throw
        // method always terminates the yield* loop.
        context.delegate = null;

        if (context.method === "throw") {
          // Note: ["return"] must be used for ES3 parsing compatibility.
          if (delegate.iterator["return"]) {
            // If the delegate iterator has a return method, give it a
            // chance to clean up.
            context.method = "return";
            context.arg = undefined$1;
            maybeInvokeDelegate(delegate, context);

            if (context.method === "throw") {
              // If maybeInvokeDelegate(context) changed context.method from
              // "return" to "throw", let that override the TypeError below.
              return ContinueSentinel;
            }
          }

          context.method = "throw";
          context.arg = new TypeError(
            "The iterator does not provide a 'throw' method");
        }

        return ContinueSentinel;
      }

      var record = tryCatch(method, delegate.iterator, context.arg);

      if (record.type === "throw") {
        context.method = "throw";
        context.arg = record.arg;
        context.delegate = null;
        return ContinueSentinel;
      }

      var info = record.arg;

      if (! info) {
        context.method = "throw";
        context.arg = new TypeError("iterator result is not an object");
        context.delegate = null;
        return ContinueSentinel;
      }

      if (info.done) {
        // Assign the result of the finished delegate to the temporary
        // variable specified by delegate.resultName (see delegateYield).
        context[delegate.resultName] = info.value;

        // Resume execution at the desired location (see delegateYield).
        context.next = delegate.nextLoc;

        // If context.method was "throw" but the delegate handled the
        // exception, let the outer generator proceed normally. If
        // context.method was "next", forget context.arg since it has been
        // "consumed" by the delegate iterator. If context.method was
        // "return", allow the original .return call to continue in the
        // outer generator.
        if (context.method !== "return") {
          context.method = "next";
          context.arg = undefined$1;
        }

      } else {
        // Re-yield the result returned by the delegate method.
        return info;
      }

      // The delegate iterator is finished, so forget it and continue with
      // the outer generator.
      context.delegate = null;
      return ContinueSentinel;
    }

    // Define Generator.prototype.{next,throw,return} in terms of the
    // unified ._invoke helper method.
    defineIteratorMethods(Gp);

    define(Gp, toStringTagSymbol, "Generator");

    // A Generator should always return itself as the iterator object when the
    // @@iterator function is called on it. Some browsers' implementations of the
    // iterator prototype chain incorrectly implement this, causing the Generator
    // object to not be returned from this call. This ensures that doesn't happen.
    // See https://github.com/facebook/regenerator/issues/274 for more details.
    Gp[iteratorSymbol] = function() {
      return this;
    };

    Gp.toString = function() {
      return "[object Generator]";
    };

    function pushTryEntry(locs) {
      var entry = { tryLoc: locs[0] };

      if (1 in locs) {
        entry.catchLoc = locs[1];
      }

      if (2 in locs) {
        entry.finallyLoc = locs[2];
        entry.afterLoc = locs[3];
      }

      this.tryEntries.push(entry);
    }

    function resetTryEntry(entry) {
      var record = entry.completion || {};
      record.type = "normal";
      delete record.arg;
      entry.completion = record;
    }

    function Context(tryLocsList) {
      // The root entry object (effectively a try statement without a catch
      // or a finally block) gives us a place to store values thrown from
      // locations where there is no enclosing try statement.
      this.tryEntries = [{ tryLoc: "root" }];
      tryLocsList.forEach(pushTryEntry, this);
      this.reset(true);
    }

    exports.keys = function(object) {
      var keys = [];
      for (var key in object) {
        keys.push(key);
      }
      keys.reverse();

      // Rather than returning an object with a next method, we keep
      // things simple and return the next function itself.
      return function next() {
        while (keys.length) {
          var key = keys.pop();
          if (key in object) {
            next.value = key;
            next.done = false;
            return next;
          }
        }

        // To avoid creating an additional object, we just hang the .value
        // and .done properties off the next function object itself. This
        // also ensures that the minifier will not anonymize the function.
        next.done = true;
        return next;
      };
    };

    function values(iterable) {
      if (iterable) {
        var iteratorMethod = iterable[iteratorSymbol];
        if (iteratorMethod) {
          return iteratorMethod.call(iterable);
        }

        if (typeof iterable.next === "function") {
          return iterable;
        }

        if (!isNaN(iterable.length)) {
          var i = -1, next = function next() {
            while (++i < iterable.length) {
              if (hasOwn.call(iterable, i)) {
                next.value = iterable[i];
                next.done = false;
                return next;
              }
            }

            next.value = undefined$1;
            next.done = true;

            return next;
          };

          return next.next = next;
        }
      }

      // Return an iterator with no values.
      return { next: doneResult };
    }
    exports.values = values;

    function doneResult() {
      return { value: undefined$1, done: true };
    }

    Context.prototype = {
      constructor: Context,

      reset: function(skipTempReset) {
        this.prev = 0;
        this.next = 0;
        // Resetting context._sent for legacy support of Babel's
        // function.sent implementation.
        this.sent = this._sent = undefined$1;
        this.done = false;
        this.delegate = null;

        this.method = "next";
        this.arg = undefined$1;

        this.tryEntries.forEach(resetTryEntry);

        if (!skipTempReset) {
          for (var name in this) {
            // Not sure about the optimal order of these conditions:
            if (name.charAt(0) === "t" &&
                hasOwn.call(this, name) &&
                !isNaN(+name.slice(1))) {
              this[name] = undefined$1;
            }
          }
        }
      },

      stop: function() {
        this.done = true;

        var rootEntry = this.tryEntries[0];
        var rootRecord = rootEntry.completion;
        if (rootRecord.type === "throw") {
          throw rootRecord.arg;
        }

        return this.rval;
      },

      dispatchException: function(exception) {
        if (this.done) {
          throw exception;
        }

        var context = this;
        function handle(loc, caught) {
          record.type = "throw";
          record.arg = exception;
          context.next = loc;

          if (caught) {
            // If the dispatched exception was caught by a catch block,
            // then let that catch block handle the exception normally.
            context.method = "next";
            context.arg = undefined$1;
          }

          return !! caught;
        }

        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          var record = entry.completion;

          if (entry.tryLoc === "root") {
            // Exception thrown outside of any try block that could handle
            // it, so set the completion value of the entire function to
            // throw the exception.
            return handle("end");
          }

          if (entry.tryLoc <= this.prev) {
            var hasCatch = hasOwn.call(entry, "catchLoc");
            var hasFinally = hasOwn.call(entry, "finallyLoc");

            if (hasCatch && hasFinally) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              } else if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }

            } else if (hasCatch) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              }

            } else if (hasFinally) {
              if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }

            } else {
              throw new Error("try statement without catch or finally");
            }
          }
        }
      },

      abrupt: function(type, arg) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.tryLoc <= this.prev &&
              hasOwn.call(entry, "finallyLoc") &&
              this.prev < entry.finallyLoc) {
            var finallyEntry = entry;
            break;
          }
        }

        if (finallyEntry &&
            (type === "break" ||
             type === "continue") &&
            finallyEntry.tryLoc <= arg &&
            arg <= finallyEntry.finallyLoc) {
          // Ignore the finally entry if control is not jumping to a
          // location outside the try/catch block.
          finallyEntry = null;
        }

        var record = finallyEntry ? finallyEntry.completion : {};
        record.type = type;
        record.arg = arg;

        if (finallyEntry) {
          this.method = "next";
          this.next = finallyEntry.finallyLoc;
          return ContinueSentinel;
        }

        return this.complete(record);
      },

      complete: function(record, afterLoc) {
        if (record.type === "throw") {
          throw record.arg;
        }

        if (record.type === "break" ||
            record.type === "continue") {
          this.next = record.arg;
        } else if (record.type === "return") {
          this.rval = this.arg = record.arg;
          this.method = "return";
          this.next = "end";
        } else if (record.type === "normal" && afterLoc) {
          this.next = afterLoc;
        }

        return ContinueSentinel;
      },

      finish: function(finallyLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.finallyLoc === finallyLoc) {
            this.complete(entry.completion, entry.afterLoc);
            resetTryEntry(entry);
            return ContinueSentinel;
          }
        }
      },

      "catch": function(tryLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          if (entry.tryLoc === tryLoc) {
            var record = entry.completion;
            if (record.type === "throw") {
              var thrown = record.arg;
              resetTryEntry(entry);
            }
            return thrown;
          }
        }

        // The context.catch method must only be called with a location
        // argument that corresponds to a known catch block.
        throw new Error("illegal catch attempt");
      },

      delegateYield: function(iterable, resultName, nextLoc) {
        this.delegate = {
          iterator: values(iterable),
          resultName: resultName,
          nextLoc: nextLoc
        };

        if (this.method === "next") {
          // Deliberately forget the last sent value so that we don't
          // accidentally pass it on to the delegate.
          this.arg = undefined$1;
        }

        return ContinueSentinel;
      }
    };

    // Regardless of whether this script is executing as a CommonJS module
    // or not, return the runtime object so that we can declare the variable
    // regeneratorRuntime in the outer scope, which allows this module to be
    // injected easily by `bin/regenerator --include-runtime script.js`.
    return exports;

  }(
    // If this script is executing as a CommonJS module, use module.exports
    // as the regeneratorRuntime namespace. Otherwise create a new empty
    // object. Either way, the resulting object will be used to initialize
    // the regeneratorRuntime variable at the top of this file.
    typeof module === "object" ? module.exports : {}
  ));

  try {
    regeneratorRuntime = runtime;
  } catch (accidentalStrictMode) {
    // This module should not be running in strict mode, so the above
    // assignment should always work unless something is misconfigured. Just
    // in case runtime.js accidentally runs in strict mode, we can escape
    // strict mode using a global Function call. This could conceivably fail
    // if a Content Security Policy forbids using Function, but in that case
    // the proper solution is to fix the accidental strict mode problem. If
    // you've misconfigured your bundler to force strict mode and applied a
    // CSP to forbid Function, and you're not willing to fix either of those
    // problems, please detail your unique predicament in a GitHub issue.
    Function("r", "regeneratorRuntime = r")(runtime);
  }

  /**
   * Detect memory exhaustion and show warning.
   */
  var WpstgDetectMemoryExhaust = /*#__PURE__*/function () {
    function WpstgDetectMemoryExhaust(wpstgObject) {
      if (wpstgObject === void 0) {
        wpstgObject = wpstg;
      }

      this.wpstgObject = wpstgObject;
    }

    var _proto = WpstgDetectMemoryExhaust.prototype;

    _proto.sendRequest = function sendRequest(requestType, callback) {
      var _this = this;

      if (callback === void 0) {
        callback = null;
      }

      fetch(this.wpstgObject.ajaxUrl, {
        method: 'POST',
        credentials: 'same-origin',
        body: new URLSearchParams({
          action: 'wpstg--detect-memory-exhaust',
          requestType: requestType,
          accessToken: this.wpstgObject.accessToken,
          nonce: this.wpstgObject.nonce
        }),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      }).then(function (response) {
        if (response.ok) {
          return response.json();
        }

        return Promise.reject(response);
      }).then(function (data) {
        if ('undefined' !== typeof data.status && data.status) {
          if (data.error && typeof callback === 'function') {
            callback(data.data, data.message);
          }

          return;
        }

        console.warn(data.message);
      })["catch"](function (error) {
        console.warn(_this.wpstgObject.i18n['somethingWentWrong'], error);
      });
    };

    return WpstgDetectMemoryExhaust;
  }();

  /**
   * Enable side bar menu and set url on tab click
   */
  var WpstgSidebarMenu = /*#__PURE__*/function () {
    function WpstgSidebarMenu() {
      this.init();
    }

    var _proto = WpstgSidebarMenu.prototype;

    _proto.init = function init() {
      this.wpstdStagingTab = document.querySelector('#wpstg--tab--toggle--staging');
      this.wpstdBackupTab = document.querySelector('#wpstg--tab--toggle--backup');
      this.wpstdSidebarMenu = document.querySelector('#toplevel_page_wpstg_clone');
      this.addEvents();
    };

    _proto.addEvents = function addEvents() {
      var _this = this;

      if (this.wpstdStagingTab !== null) {
        this.wpstdStagingTab.addEventListener('click', function () {
          _this.setPageUrl('wpstg_clone');

          _this.setSidebarMenu('wpstg_clone');
        });
      }

      if (this.wpstdBackupTab !== null) {
        this.wpstdBackupTab.addEventListener('click', function () {
          _this.setPageUrl('wpstg_backup');

          _this.setSidebarMenu('wpstg_backup');
        });
      }
    };

    _proto.setPageUrl = function setPageUrl(page) {
      window.history.pushState(null, null, window.location.pathname + '?page=' + page);
    };

    _proto.setSidebarMenu = function setSidebarMenu(page) {
      var wpstgSidebarMenuElements = this.wpstdSidebarMenu.querySelector('ul').querySelectorAll('li');

      if (wpstgSidebarMenuElements.length > 0) {
        for (var i = 0; i < wpstgSidebarMenuElements.length; i++) {
          wpstgSidebarMenuElements[i].classList.remove('current');

          if (wpstgSidebarMenuElements[i].querySelector('a') !== null) {
            if (wpstgSidebarMenuElements[i].querySelector('a').getAttribute('href') === 'admin.php?page=' + page) {
              wpstgSidebarMenuElements[i].classList.add('current');
            }
          }
        }
      }
    };

    return WpstgSidebarMenu;
  }();

  var WPStagingBackup;

  (function ($) {
    window.addEventListener('backups-tab', function () {
      WPStagingBackup.fetchListing();
      new WpstgSidebarMenu();
    });
    window.addEventListener('backupListingFinished', function () {
      fetch(ajaxurl + "?action=wpstg--backups--restore--file-list&_=" + Math.random() + "&withTemplate=true", {
        method: 'POST',
        credentials: 'same-origin',
        body: new URLSearchParams({
          action: 'wpstg--backups--restore--file-list',
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce
        }),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded'
        }
      }).then(WPStagingCommon.handleFetchErrors).then(function (res) {
        return res.json();
      }).then(function (res) {
        if (res.success !== undefined && res.success === false) {
          WPStagingCommon.showError('Error: ' + res.data);
        }

        var $ul = $('.wpstg-backup-list ul');
        $ul.empty();
        $ul.html(res);
        addEvent(qs('#wpstg-existing-backups'), 'click', '.wpstg-tab-header', function (el) {
          var target = qs(el.getAttribute('data-id'));
          el.classList.toggle('expand');

          if (el.classList.contains('expand')) {
            el.querySelector('span').classList.add('wpstg-rotate-90');
            slideDown(target);
          } else {
            el.querySelector('span').classList.remove('wpstg-rotate-90');
            slideUp(target);
          }
        });
      })["catch"](function (e) {
        return WPStagingCommon.showAjaxFatalError(e, '', 'Submit an error report.');
      });
    });
    window.addEventListener('finishedProcess', function () {
      window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
    });
    window.addEventListener('finishedProcessWithError', function () {
      window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
    });
    WPStagingBackup = {
      performingCancelRequest: false,
      isCancelled: false,
      isFinished: false,
      processInfo: {
        title: null,
        interval: null,
        isOnlySchedule: false
      },
      modal: {
        create: {
          html: null,
          confirmBtnTxt: null,
          hasBackupSchedule: null
        },
        process: {
          html: null,
          cancelBtnTxt: null,
          modal: null
        },
        download: {
          html: null,
          data: {
            indexFile: null,
            files: []
          }
        },
        restore: {
          html: null,
          btnTxtNext: null,
          btnTxtConfirm: null,
          btnTxtCancel: null,
          searchReplaceForm: null,
          containerIntroduction: null,
          data: {
            file: null,
            // file path
            fileObject: null,
            // JS "File" class instance
            search: [],
            replace: [],
            backupMetadata: {}
          },
          baseDirectory: null
        }
      },
      messages: {
        WARNING: 'warning',
        ERROR: 'error',
        INFO: 'info',
        DEBUG: 'debug',
        CRITICAL: 'critical',
        data: {
          all: [],
          info: [],
          error: [],
          critical: [],
          warning: [],
          debug: []
        },
        shouldWarn: function shouldWarn() {
          return WPStagingBackup.messages.data.error.length > 0 || WPStagingBackup.messages.data.critical.length > 0;
        },
        countByType: function countByType(type) {
          if (type === void 0) {
            type = WPStagingBackup.messages.ERROR;
          }

          return WPStagingBackup.messages.data[type].length;
        },
        addMessage: function addMessage(message) {
          if (Array.isArray(message)) {
            message.forEach(function (item) {
              WPStagingBackup.messages.addMessage(item);
            });
            return;
          }

          var type = message.type.toLowerCase() || 'info';

          if (!WPStagingBackup.messages.data[type]) {
            WPStagingBackup.messages.data[type] = [];
          }

          WPStagingBackup.messages.data.all.push(message); // TODO RPoC

          WPStagingBackup.messages.data[type].push(message);
        },
        reset: function reset() {
          WPStagingBackup.messages.data = {
            all: [],
            info: [],
            error: [],
            critical: [],
            warning: [],
            debug: []
          };
        }
      },
      timer: {
        totalSeconds: 0,
        interval: null,
        start: function start() {
          if (null !== WPStagingBackup.timer.interval) {
            return;
          }

          var prettify = function prettify(seconds) {
            console.log("Process running for " + seconds + " seconds"); // If potentially anything can exceed 24h execution time than that;
            // const _seconds = parseInt(seconds, 10)
            // const hours = Math.floor(_seconds / 3600)
            // const minutes = Math.floor(_seconds / 60) % 60
            // seconds = _seconds % 60
            //
            // return [hours, minutes, seconds]
            //   .map(v => v < 10 ? '0' + v : v)
            //   .filter((v,i) => v !== '00' || i > 0)
            //   .join(':')
            // ;
            // Are we sure we won't create anything that exceeds 24h execution time? If not then this;

            return "" + new Date(seconds * 1000).toISOString().substr(11, 8);
          };

          WPStagingBackup.timer.interval = setInterval(function () {
            $('.wpstg--modal--process--elapsed-time').text(prettify(WPStagingBackup.timer.totalSeconds));
            WPStagingBackup.timer.totalSeconds++;
          }, 1000);
        },
        stop: function stop() {
          WPStagingBackup.timer.totalSeconds = 0;

          if (WPStagingBackup.timer.interval) {
            clearInterval(WPStagingBackup.timer.interval);
            WPStagingBackup.timer.interval = null;
          }
        }
      },
      status: {
        hasResponse: null,
        reTryAfter: 5000
      },
      fetchListing: function fetchListing(isResetErrors) {
        if (isResetErrors === void 0) {
          isResetErrors = true;
        }

        WPStagingCommon.isLoading(true);
        $('#backup-messages').text('');

        if (isResetErrors) {
          WPStagingCommon.resetErrors();
        }

        return fetch(ajaxurl + "?action=wpstg--backups--listing&_=" + Math.random(), {
          method: 'POST',
          credentials: 'same-origin',
          body: new URLSearchParams({
            action: 'wpstg--backups--listing',
            accessToken: wpstg.accessToken,
            nonce: wpstg.nonce
          }),
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded'
          }
        }).then(WPStagingCommon.handleFetchErrors).then(function (res) {
          return res.json();
        }).then(function (res) {
          WPStagingCommon.cache.get('#wpstg--tab--backup').html(res);

          if (res.success !== undefined && res.success === false) {
            WPStagingCommon.showError('Error: ' + res.data);
            return;
          }

          WPStagingCommon.showAjaxFatalError(res, '', 'Submit an error report.');
          WPStagingCommon.isLoading(false);
          window.dispatchEvent(new Event('backupListingFinished'));
          return res;
        })["catch"](function (e) {
          return WPStagingCommon.showAjaxFatalError(e, '', 'Submit an error report.');
        });
      },

      /**
       * The cancel & cleanup process when we cancel a backup job or when a backup job is stopped due to an error.
       *
       * @param {Object} extraParams Extra parameter to send during cancel process
       * @param {CallableFunction} callback This function is called when a backup cancel/cleanup process response is returned. This callback is always called even if cancel process fails.
       */
      cancel: function cancel(extraParams, callback) {
        if (extraParams === void 0) {
          extraParams = {};
        }

        if (callback === void 0) {
          callback = null;
        }

        WPStagingBackup.timer.stop();
        clearInterval(WPStagingBackup.processInfo.interval);
        WPStagingBackup.isCancelled = true;
        WPStagingBackup.processInfo.interval = null;
        window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
        WPStagingCommon.closeSwalModal();
        WPStagingCommon.getSwalModal(true).fire({
          title: 'Cancelling & Cleaning up',
          text: 'This modal will close automatically when done...',
          icon: 'info',
          showConfirmButton: false,
          showCloseButton: false,
          showLoaderOnConfirm: false,
          showCancelButton: false,
          allowEscapeKey: false,
          allowOutsideClick: false,
          width: 650,
          onRender: function onRender() {
            WPStagingBackup.sendCancelRequest(Object.assign({
              isInit: 'yes'
            }, extraParams), callback);
          }
        });
      },
      sendCancelRequest: function sendCancelRequest(extraParams, callback) {
        if (WPStagingBackup.performingCancelRequest) {
          return;
        }

        WPStagingBackup.performingCancelRequest = true;
        WPStagingCommon.ajax(Object.assign({
          action: 'wpstg--backups--cancel',
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce,
          jobIdBeingCancelled: WPStagingCommon.getJobId()
        }, extraParams), function (response) {
          WPStagingBackup.performingCancelRequest = false;
          WPStagingBackup.isCancelled = false;
          WPStagingCommon.showAjaxFatalError(response, '', 'Submit an error report.');

          if (!response.hasOwnProperty('status')) {
            WPStagingCommon.showErrorModal('Cancel process did not finish gracefully. Some temporary files might not have been cleaned up.');
          }

          if (response.status === true) {
            WPStagingCommon.closeSwalModal();

            if (callback !== undefined && callback !== null) {
              callback();
            }
          } else {
            extraParams.isInit = 'no';
            WPStagingBackup.sendCancelRequest(extraParams, callback);
          }
        }, 'json', false, 10, // Don't retry upon failure
        1.25, function (xhr, textStatus, errorThrown) {
          WPStagingBackup.performingCancelRequest = false; // Todo: Why do we need this?

          WPStagingCommon.continueErrorHandle = false; // Resource is busy, wait for request to finish and try again

          if (xhr.status === 423) {
            setTimeout(function () {
              WPStagingBackup.sendCancelRequest(extraParams, callback);
            }, 1000);
            return;
          }

          WPStagingCommon.closeSwalModal();
          WPStagingCommon.showErrorModal('Cancel process did not finish gracefully. Some temporary files might not have been cleaned up.');

          if (callback !== undefined && callback !== null) {
            callback();
          }
        });
      },

      /**
      * If process.execute exists, process.data and process.onResponse is not used
      * process = { data: {}, onResponse: (resp) => {}, onAfterClose: () => {}, execute: () => {}, isShowCancelButton: bool }
      * @param {object} process
      */
      process: function process(_process) {
        if (typeof _process.execute !== 'function' && (!_process.data || !_process.onResponse)) {
          WPStagingCommon.closeSwalModal();
          WPStagingCommon.showError('process.data and / or process.onResponse is not set');
          return;
        } // TODO move to backend and get the contents as xhr response?


        if (!WPStagingBackup.modal.process.html || !WPStagingBackup.modal.process.cancelBtnTxt) {
          var $modal = $('#wpstg--modal--backup--process');
          var html = $modal.html();
          var btnTxt = $modal.attr('data-cancelButtonText');
          WPStagingBackup.modal.process.html = html || null;
          WPStagingBackup.modal.process.cancelBtnTxt = btnTxt || null;
          $modal.remove();
        }

        $('body').off('click', '.wpstg--modal--process--logs--tail').on('click', '.wpstg--modal--process--logs--tail', function (e) {
          var logBtn = $(this);
          e.preventDefault();
          var container = WPStagingCommon.getSwalContainer();
          var $logs = $(container).find('.wpstg--modal--process--logs');
          $logs.toggle();

          if ($logs.is(':visible')) {
            logBtn.text(wpstg.i18n.hideLogs);
            container.childNodes[0].style.width = '97%';
            container.style['z-index'] = 9999;
          } else {
            logBtn.text(wpstg.i18n.showLogs);
            container.childNodes[0].style.width = '600px';
          }
        });
        _process.isShowCancelButton = false !== _process.isShowCancelButton;
        WPStagingBackup.modal.process.modal = WPStagingCommon.getSwalModal(true, {
          content: 'wpstg--process--content'
        }).fire({
          html: WPStagingBackup.modal.process.html,
          cancelButtonText: WPStagingBackup.modal.process.cancelBtnTxt,
          showCancelButton: _process.isShowCancelButton,
          showConfirmButton: false,
          allowOutsideClick: false,
          allowEscapeKey: false,
          width: 600,
          onRender: function onRender() {
            var _btnCancel = WPStagingCommon.getSwalContainer().getElementsByClassName('wpstg--swal2-cancel wpstg--btn--cancel')[0];

            var btnCancel = _btnCancel.cloneNode(true);

            _btnCancel.parentNode.replaceChild(btnCancel, _btnCancel);

            btnCancel.addEventListener('click', function (e) {
              if (confirm('Do you want to cancel the process?')) {
                WPStagingBackup.cancel();
              }
            });

            if (typeof _process.execute === 'function') {
              _process.execute();

              return;
            }

            if (!_process.data || !_process.onResponse) {
              WPStagingCommon.closeSwalModal();
              WPStagingCommon.showError('process.data and / or process.onResponse is not set');
              return;
            }

            WPStagingCommon.ajax(_process.data, _process.onResponse);
          },
          onAfterClose: function onAfterClose() {
            return typeof _process.onAfterClose === 'function' && _process.onAfterClose();
          }
        });
      },
      processResponse: function processResponse(response) {
        if (response === null) {
          WPStagingCommon.closeSwalModal();
          WPStagingCommon.showError('Invalid Response; null');
          throw new Error("Invalid Response; " + response);
        }

        var $container = $(WPStagingCommon.getSwalContainer());

        var title = function title() {
          if (response.title || response.statusTitle) {
            $container.find('.wpstg--modal--process--title').text(response.title || response.statusTitle);
          }
        };

        var percentage = function percentage() {
          if (response.percentage) {
            $container.find('.wpstg--modal--process--percent').text(response.percentage);
          }
        };

        var logs = function logs() {
          if (!response.messages) {
            return;
          }

          var $logsContainer = $container.find('.wpstg--modal--process--logs');
          var stoppingTypes = [WPStagingBackup.messages.ERROR, WPStagingBackup.messages.CRITICAL];

          var appendMessage = function appendMessage(message) {
            if (Array.isArray(message)) {
              for (var _iterator = _createForOfIteratorHelperLoose(message), _step; !(_step = _iterator()).done;) {
                var item = _step.value;
                appendMessage(item);
              }

              return;
            }

            var msgClass = "wpstg--modal--process--msg--" + message.type.toLowerCase();
            $logsContainer.append("<p class=\"" + msgClass + "\">[" + message.type + "] - [" + message.date + "] - " + message.message + "</p>");

            if (stoppingTypes.includes(message.type.toLowerCase())) {
              window.dispatchEvent(new CustomEvent('finishedProcessWithError', {
                detail: {
                  error: message.message
                }
              })); // Callback approach is used to make sure the logs modal is always shown,
              // after the completion of cancel/cleanup process.
              // Makes sure cancel/cleanup process doesn't close the logs modal.
              // Any other approach would have required a lot of refactoring.

              WPStagingBackup.cancel({}, function () {
                setTimeout(WPStagingBackup.logsModal, 500);
              });
            }
          };

          for (var _iterator2 = _createForOfIteratorHelperLoose(response.messages), _step2; !(_step2 = _iterator2()).done;) {
            var message = _step2.value;

            if (!message) {
              continue;
            }

            WPStagingBackup.messages.addMessage(message);
            appendMessage(message);
          }

          if ($logsContainer.is(':visible')) {
            $logsContainer.scrollTop($logsContainer[0].scrollHeight);
          }

          if (!WPStagingBackup.messages.shouldWarn()) {
            return;
          }

          var $btnShowLogs = $container.find('.wpstg--modal--process--logs--tail');
          $btnShowLogs.html($btnShowLogs.attr('data-txt-bad'));
          $btnShowLogs.find('.wpstg--modal--logs--critical-count').text(WPStagingBackup.messages.countByType(WPStagingBackup.messages.CRITICAL));
          $btnShowLogs.find('.wpstg--modal--logs--error-count').text(WPStagingBackup.messages.countByType(WPStagingBackup.messages.ERROR));
          $btnShowLogs.find('.wpstg--modal--logs--warning-count').text(WPStagingBackup.messages.countByType(WPStagingBackup.messages.WARNING));
        };

        title();
        percentage();
        logs();

        if (response.jobId) {
          WPStagingCommon.setJobId(response.jobId);
        }

        if (response.status === true && response.job_done === true) {
          WPStagingBackup.timer.stop();
          WPStagingBackup.isCancelled = true;
          window.dispatchEvent(new CustomEvent('finishedProcess', {
            response: response
          }));
        }
      },
      logsModal: function logsModal() {
        WPStagingCommon.getSwalModal(true, {
          popup: 'wpstg-swal-popup centered-modal'
        }).fire({
          html: "<div class=\"wpstg--modal--error--logs\" style=\"display:block\"></div><div class=\"wpstg--modal--process--logs\" style=\"display:block\"></div>",
          width: '97%',
          onRender: function onRender() {
            var $container = $(WPStagingCommon.getSwalContainer());
            $container[0].style['z-index'] = 9999;
            var $logsContainer = $container.find('.wpstg--modal--process--logs');
            var $errorContainer = $container.find('.wpstg--modal--error--logs');
            var $translations = $('#wpstg--js--translations');
            var messages = WPStagingBackup.messages;
            var title = $translations.attr('data-modal-logs-title').replace('{critical}', messages.countByType(messages.CRITICAL)).replace('{errors}', messages.countByType(messages.ERROR)).replace('{warnings}', messages.countByType(messages.WARNING));
            $errorContainer.before("<h3>" + title + "</h3>");
            var warnings = [WPStagingBackup.messages.CRITICAL, WPStagingBackup.messages.ERROR, WPStagingBackup.messages.WARNING];

            if (!WPStagingBackup.messages.shouldWarn()) {
              $errorContainer.hide();
            }

            for (var _iterator3 = _createForOfIteratorHelperLoose(messages.data.all), _step3; !(_step3 = _iterator3()).done;) {
              var message = _step3.value;
              var msgClass = "wpstg--modal--process--msg--" + message.type.toLowerCase();

              if (warnings.includes(message.type)) {
                $errorContainer.append("<p class=\"" + msgClass + "\">[" + message.type + "] - [" + message.date + "] - " + message.message + "</p>");
              }

              $logsContainer.append("<p class=\"" + msgClass + "\">[" + message.type + "] - [" + message.date + "] - " + message.message + "</p>");
            }
          },
          onOpen: function onOpen(container) {
            var $logsContainer = $(container).find('.wpstg--modal--process--logs');
            $logsContainer.scrollTop($logsContainer[0].scrollHeight);
          }
        });
      },
      downloadModal: function downloadModal(_ref) {
        var _ref$title = _ref.title,
            title = _ref$title === void 0 ? null : _ref$title,
            _ref$bodyText = _ref.bodyText,
            bodyText = _ref$bodyText === void 0 ? null : _ref$bodyText;

        if (null === WPStagingBackup.modal.download.html) {
          var $el = $('#wpstg--modal--backup--download');
          WPStagingBackup.modal.download.html = $el.html();
          $el.remove();
        }

        WPStagingCommon.getSwalModal(true).fire({
          'icon': 'success',
          'html': WPStagingBackup.modal.download.html.replace('{title}', title).replace('{btnTxtLog}', '<span style="text-decoration: underline">Show Logs</span>').replace('{text}', bodyText !== null ? bodyText : 'You can download or restore this backup at any time on this website or even on another website to transfer this site.'),
          'confirmButtonText': 'Close',
          'showCancelButton': false,
          'showConfirmButton': true
        });
      },
      checkMemoryExhaustion: function checkMemoryExhaustion(response, requestType) {
        var detectMemoryExhaust = new WpstgDetectMemoryExhaust();
        detectMemoryExhaust.sendRequest(requestType, function (data, message) {
          response.messages = [{
            'type': 'critical',
            'date': data['time'],
            'message': message + '. Visit <a target="_blank" href="' + WPStagingCommon.memoryExhaustArticleLink + '">this article</a> for more detail. Please contact WP Staging support if you need help.'
          }];
          WPStagingBackup.processResponse(response);
        });
      },
      statusStop: function statusStop() {
        clearInterval(WPStagingBackup.processInfo.interval);
        WPStagingBackup.processInfo.interval = null;
        window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
      },
      statusStart: function statusStart(process) {
        if (WPStagingBackup.processInfo.interval !== null) {
          return;
        } // console.log('Status: Start 2');


        WPStagingBackup.processInfo.interval = setInterval(function () {
          if (true === WPStagingBackup.isCancelled) {
            WPStagingBackup.statusStop();
            return;
          }

          if (WPStagingBackup.status.hasResponse === false) {
            return;
          }

          WPStagingBackup.status.hasResponse = false;
          fetch(ajaxurl + "?action=wpstg--backups--status&" + process + "=restore", {
            method: 'POST',
            credentials: 'same-origin',
            body: new URLSearchParams({
              action: 'wpstg--backups--status',
              accessToken: wpstg.accessToken,
              nonce: wpstg.nonce
            }),
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded'
            }
          }).then(function (res) {
            return res.json();
          }).then(function (res) {
            WPStagingBackup.status.hasResponse = true;

            if (typeof res === 'undefined') {
              WPStagingBackup.statusStop();
            }

            if (WPStagingBackup.processInfo.title === res.currentStatusTitle) {
              return;
            }

            WPStagingBackup.processInfo.title = res.currentStatusTitle;
            var $container = $(WPStagingCommon.getSwalContainer());
            $container.find('.wpstg--modal--process--title').text(res.currentStatusTitle);
            $container.find('.wpstg--modal--process--percent').text('0');
          })["catch"](function (e) {
            WPStagingBackup.status.hasResponse = true;
            WPStagingCommon.showAjaxFatalError(e, '', 'Submit an error report.');
          });
        }, 5000);
      }
    };
  })(jQuery);

  var WPStagingBackup$1 = WPStagingBackup;

  var WPStagingBackupEditSchedules;

  (function ($) {
    WPStagingBackupEditSchedules = {
      listen: function listen() {
        $('body').on('click', '.wpstg--edit-schedule', WPStagingBackupEditSchedules.updateSchedule);
      },
      updateSchedule: function updateSchedule(e) {
        WPStagingCommon.resetErrors();
        e.preventDefault();
        var scheduleId = e.target.dataset.scheduleId;
        WPStagingCommon.ajax({
          action: 'wpstg--backups-edit-schedule-modal',
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce,
          scheduleId: scheduleId
        }, function (response) {
          WPStagingCommon.getSwalModal(false).fire({
            html: document.getElementById('wpstg--modal--edit--backup--schedules').innerHTML,
            showConfirmButton: true,
            showCloseButton: true,
            showLoaderOnConfirm: false,
            showCancelButton: true,
            confirmButtonText: 'Save',
            cancelButtonText: 'Cancel',
            width: 750,
            allowEscapeKey: true,
            allowOutsideClick: true
          }).then(function (res) {
            if (res.isConfirmed !== true) {
              return;
            }

            var container = WPStagingCommon.getSwalContainer();
            var formValues = {
              scheduleRecurrence: container.querySelector('#backupScheduleRecurrence').value || null,
              scheduleTime: container.querySelector('#backupScheduleTime').value || null,
              scheduleRotation: container.querySelector('#backupScheduleRotation').value || null
            };
            WPStagingCommon.ajax({
              action: 'wpstg--backups-edit-schedule',
              accessToken: wpstg.accessToken,
              nonce: wpstg.nonce,
              scheduleId: scheduleId,
              formValues: formValues
            }, function (response) {
              if (response.success) {
                WPStagingBackup$1.fetchListing();
              } else if (response.data) {
                WPStagingCommon.showErrorModal(response.data);
              }
            });
            return;
          });
          qs('.wpstg--swal2-container #wpstg--modal--edit--backup--schedules--content').innerHTML = response.data;
        });
      }
    };
  })(jQuery);

  var WPStagingBackupEditSchedules$1 = WPStagingBackupEditSchedules;

  var WPStagingPro = function ($) {
    var that = {
      isCancelled: false,
      isFinished: false,
      getLogs: false,
      tableSelector: null,
      fileSelector: null,
      directoryNavigator: null,
      notyf: null
    }; // Cache Elements

    var cache = {
      elements: []
    };
    /**
       * Get / Set Cache for Selector
       * @param {String} selector
       * @return {*}
       */

    cache.get = function (selector) {
      // It is already cached!
      if ($.inArray(selector, cache.elements) !== -1) {
        return cache.elements[selector];
      } // Create cache and return


      cache.elements[selector] = jQuery(selector);
      return cache.elements[selector];
    };
    /**
       * Refreshes given cache
       * @param {String} selector
       */


    cache.refresh = function (selector) {
      selector.elements[selector] = jQuery(selector);
    };
    /**
       * Ajax Scanning before starting push process
       */


    var startScanning = function startScanning() {
      // Scan db and file system
      var $workFlow = cache.get('#wpstg-workflow');
      $workFlow // Load scanning data
      .on('click', '.wpstg-push-changes', function (e) {
        var currentObj = this;
        WPStaging.checkUserDbPermissions('push').then(function (data) {
          e.preventDefault();
          var $this = $(currentObj); // Disable button

          if ($this.attr('disabled')) {
            return false;
          } // Add loading overlay


          $workFlow.addClass('loading'); // Get clone id

          var cloneID = $(currentObj).data('clone'); // Prepare data

          that.data = {
            action: 'wpstg_scan',
            clone: cloneID,
            accessToken: wpstg.accessToken,
            nonce: wpstg.nonce
          }; // Send ajax request

          WPStaging.ajax(that.data, function (response) {
            if (response.length < 1) {
              showError('Something went wrong! No response.  Go to WP Staging > Settings and lower \'File Copy Limit\' and \'DB Query Limit\'. Also set \'CPU Load Priority to low \'' + 'and try again. If that does not help, ' + '<a href=\'https://wp-staging.com/support/\' target=\'_blank\'>open a support ticket</a> ');
            } // Styling of elements


            $workFlow.removeClass('loading').html(response);
            WPStaging.switchStep(2);
            cache.get('.wpstg-step3-cloning').hide();
            cache.get('.wpstg-step3-pushing').show();
            cache.get('.wpstg-loader').hide();
            that.directoryNavigator = new WpstgDirectoryNavigation('#wpstg-scanning-files', '#wpstg-workflow', wpstg, that.notyf);
            that.directoryNavigator.countSelectedFiles();
            that.tableSelector = new WpstgPushTableSelection();
            that.fileSelector = new WpstgPushFileSelection();
            that.tableSelector.countSelectedTables();
            that.fileSelector.countSelectedFiles();
          }, 'HTML');
        });
      }) // Previous Button
      .on('click', '.wpstg-prev-step-link', function (e) {
        e.preventDefault();
        WPStaging.loadOverview();
      }).on('click', '#wpstg-use-target-dir', function (e) {
        e.preventDefault();
        $('#wpstg_clone_dir').val(this.getAttribute('data-path'));
      }).on('click', '#wpstg-use-target-hostname', function (e) {
        e.preventDefault();
        $('#wpstg_clone_hostname').val(this.getAttribute('data-uri'));
      }).on('change', '#wpstg-delete-upload-before-pushing', function (e) {
        if (e.currentTarget.checked) {
          $('#wpstg-backup-upload-container').show();
        } else {
          $('#wpstg-backup-upload-container').hide();
          $('#wpstg-backup-upload-before-pushing').removeAttr('checked');
        }
      });
    }; // Start the whole pushing process


    var startProcess = function startProcess() {
      var $workFlow = cache.get('#wpstg-workflow'); // Click push changes button

      $workFlow.on('click', '#wpstg-push-changes', function (e) {
        e.preventDefault(); // Hide db tables and folder selection

        cache.get('.wpstg-tabs-wrapper').hide();
        cache.get('#wpstg-push-changes').hide(); // Show confirmation modal

        var cloneName = cache.get('#wpstg-push-changes').data('clone-name');
        var html = '<p class=\'wpstg-push-confirmation-message\'>This will overwrite the production/live site and its plugins, themes and media assets with data from the staging site: "' + cloneName + '".  <br/><br/>Database data will be overwritten for each selected table. Take care if you use a shop system like WooCommerce and read the <a href="https://wp-staging.com/docs/skip-woocommerce-orders-and-products/" target="_blank">FAQ</a>. <br/><br/><b>Important:</b> Before you proceed make sure that you have a full site backup. If the pushing process is not successful contact us at <a href=\'mailto:support@wp-staging.com\'>support@wp-staging.com</a> or use the Contact Us button.</p>';
        confirmModal('Confirm Push!', html, 'Push', 'wpstg-confirm-push').then(function (result) {
          if (result.value) {
            cache.get('#wpstg-push-changes').attr('disabled', true);
            cache.get('.wpstg-prev-step-link').attr('disabled', true);
            cache.get('#wpstg-scanning-files').hide();
            cache.get('.wpstg-progress-bar-wrapper').show();
            cache.get('#wpstg-cancel-pushing').show(); // show cancel button

            WPStaging.switchStep(3);
            window.addEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
            processing();
            return;
          } // Show db tables and folder selection


          cache.get('.wpstg-tabs-wrapper').show();
          cache.get('#wpstg-push-changes').show();
        });
      }) // Cancel pushing process
      .on('click', '#wpstg-cancel-pushing', function () {
        if (!confirm('Are you sure you want to cancel pushing process?')) {
          return false;
        }

        cancelPushingProcess();
      });
    };

    var cancelPushingProcess = function cancelPushingProcess() {
      WPStaging.ajax({
        action: 'wpstg_cancel_push_processing',
        accessToken: wpstg.accessToken,
        nonce: wpstg.nonce
      }, function (response) {
        if (response.success) {
          that.isCancelled = true;
          cache.get('.wpstg-loader').hide();
          cache.get('#wpstg-cancel-pushing').hide();
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          WPStaging.loadOverview();
          return;
        }
      }, 'json', false);
    };
    /**
       * Start ajax processing
       * @return string
       */


    var processing = function processing() {
      // Show loader gif
      cache.get('.wpstg-loader').show(); // Show logging window

      cache.get('.wpstg-log-details').show(); // Get clone id

      var cloneID = cache.get('#wpstg-push-changes').data('clone');
      var deleteUploadsBeforePush = cache.get('#wpstg-delete-upload-before-pushing')[0].checked;
      var backupUploadsBeforePush = false;

      if (deleteUploadsBeforePush) {
        backupUploadsBeforePush = cache.get('#wpstg-backup-upload-before-pushing')[0].checked;
      }

      var includedTables = getSelectedTablesToPush();
      var excludedTables = getExcludedTables();
      var allTablesExcluded = false;
      that.isCancelled = false;

      if (includedTables.length > excludedTables.length) {
        includedTables = '';
      } else if (excludedTables.length > includedTables.length) {
        excludedTables = '';
        allTablesExcluded = includedTables === '';
      }

      WPStaging.ajax({
        action: 'wpstg_push_processing',
        accessToken: wpstg.accessToken,
        nonce: wpstg.nonce,
        clone: cloneID,
        includedTables: includedTables,
        excludedTables: excludedTables,
        allTablesExcluded: allTablesExcluded,
        selectedTablesWithoutPrefix: getSelectedTablesWithoutPrefix(),
        includedDirectories: getIncludedDirectories(),
        excludedDirectories: getExcludedDirectories(),
        extraDirectories: getIncludedExtraDirectories(),
        createBackupBeforePushing: cache.get('#wpstg-create-backup-before-pushing')[0].checked,
        deletePluginsAndThemes: cache.get('#wpstg-remove-uninstalled-plugins-themes')[0].checked,
        deleteUploadsBeforePushing: deleteUploadsBeforePush,
        backupUploadsBeforePushing: backupUploadsBeforePush
      }, function (response) {
        if (that.isCancelled) {
          cancelPushingProcess();
          cache.get('.wpstg-loader').hide();
          cache.get('#wpstg-cancel-pushing').hide();
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          return;
        } // Undefined Error


        if (false === response) {
          showError('Something went wrong! Error: No response.  Go to WP Staging > Settings and lower \'File Copy Limit\' and \'DB Query Limit\'. Also set \'CPU Load Priority to low \'' + 'and try again. If that does not help, ' + '<a href=\'https://wp-staging.com/support/\' target=\'_blank\'>open a support ticket</a> ');
          cache.get('.wpstg-loader').hide();
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          return;
        } // Throw Error


        if ('undefined' !== typeof response.error && response.error) {
          WPStaging.showError('Something went wrong! Error: ' + response.message + '.  Go to WP Staging > Settings and lower \'File Copy Limit\' and \'DB Query Limit\'. Also set \'CPU Load Priority to low \'' + 'and try again. If that does not help, ' + '<a href=\'https://wp-staging.com/support/\' target=\'_blank\'>open a support ticket</a> ');
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          return;
        } // Add Log messages


        if ('undefined' !== typeof response.last_msg && response.last_msg) {
          WPStaging.getLogs(response.last_msg);
        } // Continue processing


        if (false === response.status) {
          progressBar(response);
          setTimeout(function () {
            cache.get('.wpstg-loader').show();
            processing();
          }, wpstg.delayReq);
        } else if (true === response.status) {
          progressBar(response);
          processing();
        } else if ('finished' === response.status || 'undefined' !== typeof response.job_done && response.job_done) {
          window.removeEventListener('beforeunload', WPStaging.warnIfClosingDuringProcess);
          isFinished(response);
        }
      }, 'json', false);
    };
    /**
       * Test database connection
       * @return object
       */


    var connectDatabase = function connectDatabase() {
      var $workFlow = cache.get('#wpstg-workflow');
      $workFlow.on('click', '#wpstg-db-connect', function (e) {
        e.preventDefault();
        cache.get('.wpstg-loader').show();
        cache.get('#wpstg-db-status').hide();
        WPStaging.ajax({
          action: 'wpstg_database_connect',
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce,
          databaseUser: cache.get('#wpstg_db_username').val(),
          databasePassword: cache.get('#wpstg_db_password').val(),
          databaseServer: cache.get('#wpstg_db_server').val(),
          databaseDatabase: cache.get('#wpstg_db_database').val(),
          databasePrefix: cache.get('#wpstg_db_prefix').val(),
          databaseSsl: cache.get('#wpstg_db_ssl').is(':checked')
        }, function (response) {
          // Undefined Error
          if (false === response) {
            showError('Something went wrong! Error: No response.' + 'Please try again. If that does not help, ' + '<a href=\'https://wp-staging.com/support/\' target=\'_blank\'>open a support ticket</a> ');
            cache.get('.wpstg-loader').hide();
            cache.get('#wpstg-db-status').remove();
            cache.get('#wpstg-error-details').hide();
            cache.get('#wpstg-db-connect').after('<span id="wpstg-db-status" class="wpstg-failed"> Failed</span>');
            return;
          } // Throw Error


          if ('undefined' !== typeof response.errors && response.errors) {
            WPStaging.showError('Something went wrong! Error: ' + response.errors + ' Please try again. If that does not help, ' + '<a href=\'https://wp-staging.com/support/\' target=\'_blank\'>open a support ticket</a> ');
            cache.get('.wpstg-loader').hide();
            cache.get('#wpstg-db-status').hide();
            cache.get('#wpstg-db-error').remove();
            cache.get('#wpstg-db-connect').after('<span id="wpstg-db-status" class="wpstg-failed"> Failed</span><br/><span id="wpstg-db-error" class="wpstg--red">Error: ' + response.errors + '</span>');
            return;
          }

          if ('undefined' !== typeof response.success && response.success) {
            cache.get('.wpstg-loader').hide();
            cache.get('#wpstg-db-status').hide();
            cache.get('#wpstg-error-details').hide();
            cache.get('#wpstg-db-error').hide();
            cache.get('#wpstg-db-connect').after('<span id="wpstg-db-status" class="wpstg-success"> Success</span>');
          }
        }, 'json', false);
      }); // Make form fields editable

      $workFlow.on('click', '#wpstg-ext-db', function () {
        if (this.checked) {
          cache.get('#wpstg_db_server').removeAttr('readonly');
          cache.get('#wpstg_db_username').removeAttr('readonly');
          cache.get('#wpstg_db_password').removeAttr('readonly');
          cache.get('#wpstg_db_database').removeAttr('readonly');
          cache.get('#wpstg_db_prefix').removeAttr('readonly');
          cache.get('#wpstg_db_ssl').removeAttr('readonly');
        } else {
          cache.get('#wpstg_db_server').attr('readonly', true).val('');
          cache.get('#wpstg_db_username').attr('readonly', true).val('');
          cache.get('#wpstg_db_password').attr('readonly', true).val('');
          cache.get('#wpstg_db_database').attr('readonly', true).val('');
          cache.get('#wpstg_db_prefix').attr('readonly', true).val('');
          cache.get('#wpstg_db_ssl').attr('readonly', true).prop('checked', false);
        }
      });
    };

    var editCloneData = function editCloneData() {
      // Scan db and file system
      var $workFlow = cache.get('#wpstg-workflow');
      $workFlow // Load scanning data
      .on('click', '.wpstg-edit-clone-data', function (e) {
        e.preventDefault();
        var $this = $(this); // Disable button

        if ($this.attr('disabled')) {
          return false;
        } // Get clone id


        var cloneID = $(this).data('clone'); // Prepare data

        that.data = {
          action: 'wpstg_edit_clone_data',
          clone: cloneID,
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce
        }; // Send ajax request

        WPStaging.ajax(that.data, function (response) {
          $workFlow.html(response);
        }, 'HTML');
      }).on('click', '.wpstg-prev-step-link', function (e) {
        e.preventDefault();
        WPStaging.loadOverview();
      }).on('click', '#wpstg-save-clone-data', function (e) {
        e.preventDefault();
        var idPrefix = '#wpstg-edit-clone-data-';
        var cloneID = cache.get(idPrefix + 'clone-id').val();
        var cloneName = cache.get(idPrefix + 'clone-name').val();
        var directoryName = cache.get(idPrefix + 'directory-name').val();
        var path = cache.get(idPrefix + 'path').val();
        var url = cache.get(idPrefix + 'url').val();
        var prefix = cache.get(idPrefix + 'prefix').val();
        var externalDBUser = cache.get(idPrefix + 'database-user').val();
        var externalDBPassword = cache.get(idPrefix + 'database-password').val();
        var externalDBDatabase = cache.get(idPrefix + 'database-database').val();
        var externalDBHost = cache.get(idPrefix + 'database-server').val();
        var externalDBPrefix = cache.get(idPrefix + 'database-prefix').val();
        var externalDBSsl = cache.get(idPrefix + 'database-ssl').is(':checked'); // Prepare data

        that.data = {
          action: 'wpstg_save_clone_data',
          clone: cloneID,
          cloneName: cloneName,
          directoryName: directoryName,
          path: path,
          url: url,
          prefix: prefix,
          externalDBUser: externalDBUser,
          externalDBPassword: externalDBPassword,
          externalDBDatabase: externalDBDatabase,
          externalDBHost: externalDBHost,
          externalDBPrefix: externalDBPrefix,
          externalDBSsl: externalDBSsl,
          accessToken: wpstg.accessToken,
          nonce: wpstg.nonce
        };
        WPStaging.ajax(that.data, function (response) {
          if (response === 'Success') {
            WPStaging.loadOverview();
          } else {
            alert(response);
          }
        }, 'HTML');
      });
    };
    /**
       * All jobs are finished
       * @param {object} response
       * @return object
       */


    var isFinished = function isFinished(response) {
      progressBar(response);
      cache.get('.wpstg-loader').hide();
      cache.get('.wpstg-prev-step-link').attr('disabled', false);
      cache.get('#wpstg-cancel-pushing').hide();
      WPStagingCommon.getSwalModal(true, {
        confirmButton: 'wpstg--btn--confirm wpstg-green-button wpstg-button wpstg-link-btn wpstg-100-width',
        popup: 'wpstg-swal-popup wpstg-push-finished centered-modal'
      }).fire({
        title: 'Push Successful!',
        icon: 'success',
        html: 'Clear the site cache if changes are not visible!',
        width: '500px',
        focusConfirm: true
      });
    };
    /**
       * Get Included (Selected) Prefixed Database Tables
       * @return {Array}
       */


    var getSelectedTablesToPush = function getSelectedTablesToPush() {
      if (that.tableSelector === null) {
        return '';
      }

      return that.tableSelector.getIncludedTables();
    };
    /**
       * Get Excluded (Unchecked) Prefixed Database Tables
       * @return {Array}
       */


    var getExcludedTables = function getExcludedTables() {
      if (that.tableSelector === null) {
        return '';
      }

      return that.tableSelector.getExcludedTables();
    };
    /**
       * Get Non prefixed selected Database Tables
       * @return {Array}
       */


    var getSelectedTablesWithoutPrefix = function getSelectedTablesWithoutPrefix() {
      if (that.tableSelector === null) {
        return '';
      }

      return that.tableSelector.getSelectedTablesWithoutPrefix();
    };
    /**
       * A confirmation modal
       *
       * @param html
       * @param confirmText
       * @param confirmButtonClass
       * @return Promise
       */


    var confirmModal = function confirmModal(title, html, confirmText, confirmButtonClass) {
      return WPStagingCommon.getSwalModal(false, {
        container: 'wpstg-swal-push-container',
        confirmButton: confirmButtonClass + ' wpstg--btn--confirm wpstg-blue-primary wpstg-button wpstg-link-btn'
      }).fire({
        title: title,
        icon: 'warning',
        html: html,
        width: '750px',
        focusConfirm: false,
        confirmButtonText: confirmText,
        showCancelButton: true
      });
    };
    /**
       * Get Included Directories
       * @return {Array}
       */


    var getIncludedDirectories = function getIncludedDirectories() {
      var includedDirectories = [];
      $('.wpstg-dir input:checked').each(function () {
        var $this = $(this);

        if (!$this.parent('.wpstg-dir').parents('.wpstg-dir').children('.wpstg-expand-dirs').hasClass('disabled')) {
          includedDirectories.push($this.val());
        }
      });
      return includedDirectories;
    };
    /**
       * Get Excluded Directories
       * @return {Array}
       */


    var getExcludedDirectories = function getExcludedDirectories() {
      var excludedDirectories = [];
      $('.wpstg-dir input:not(:checked)').each(function () {
        var $this = $(this);
        excludedDirectories.push($this.val());
      });
      return excludedDirectories;
    };
    /**
       * Get Included Extra Directories
       * @return {Array}
       */


    var getIncludedExtraDirectories = function getIncludedExtraDirectories() {
      var extraDirectories = [];

      if (!$('#wpstg_extraDirectories').val()) {
        return extraDirectories;
      }

      var extraDirectories = $('#wpstg_extraDirectories').val().split(/\r?\n/);
      return extraDirectories;
    };

    var progressBar = function progressBar(response, restart) {
      if ('undefined' === typeof response.percentage) {
        return false;
      }

      if (response.job === 'JobCreateBackup') {
        cache.get('#wpstg-progress-backup').width(response.percentage * 0.15 + '%').html(response.percentage + '%');
        cache.get('#wpstg-processing-status').html(response.percentage.toFixed(0) + '%' + ' - Step 1 of 4 Creating backup...');
      }

      if (response.job === 'jobFileScanning' || response.job === 'jobCopy') {
        cache.get('#wpstg-progress-backup').css('background-color', '#3bc36b');
        cache.get('#wpstg-progress-backup').html('1. Backup'); // Assumption: All previous steps are done.
        // This avoids bugs where some steps are skipped and the progress bar is incomplete as a result

        cache.get('#wpstg-progress-backup').width('15%');
        var percentage;

        if (response.job === 'jobFileScanning') {
          percentage = response.percentage / 2;
        } else {
          percentage = 50 + response.percentage / 2;
        }

        cache.get('#wpstg-progress-files').width(percentage * 0.3 + '%').html(percentage.toFixed(0) + '%');
        cache.get('#wpstg-processing-status').html(percentage.toFixed(0) + '%' + ' - Step 2 of 4 Copying files...');
      }

      if (response.job === 'jobCopyDatabaseTmp' || response.job === 'jobSearchReplace' || response.job === 'jobData') {
        cache.get('#wpstg-progress-files').css('background-color', '#3bc36b');
        cache.get('#wpstg-progress-files').html('2. Files');
        cache.get('#wpstg-progress-files').width('30%');
        var _percentage = 0;

        if (response.job === 'jobCopyDatabaseTmp') {
          _percentage = response.percentage / 3;
        } else if (response.job === 'jobSearchReplace') {
          _percentage = 100 / 3 + response.percentage / 3;
        } else {
          _percentage = 200 / 3 + response.percentage / 3;
        }

        cache.get('#wpstg-progress-data').width(_percentage * 0.4 + '%').html(_percentage.toFixed(0) + '%');
        cache.get('#wpstg-processing-status').html(_percentage.toFixed(0) + '%' + ' - Step 3 of 4 Copying data...');
      }

      if (response.job === 'jobDatabaseRename') {
        cache.get('#wpstg-progress-data').css('background-color', '#3bc36b');
        cache.get('#wpstg-progress-data').html('3. Data');
        cache.get('#wpstg-progress-data').width('40%');
        cache.get('#wpstg-progress-finishing').width(response.percentage * 0.15 + '%').html(response.percentage + '%');
        cache.get('#wpstg-processing-status').html(response.percentage.toFixed(0) + '%' + ' - Step 4 of 4 Finishing migration...');
      }

      if (response.status === 'finished') {
        cache.get('#wpstg-progress-finishing').css('background-color', '#3bc36b');
        cache.get('#wpstg-progress-finishing').html('4. Finishing migration');
        cache.get('#wpstg-progress-finishing').width('15%');
        cache.get('#wpstg-processing-status').html(response.percentage.toFixed(0) + '%' + ' - Pushing Process Finished');
      }
    };

    that.init = function () {
      startProcess();
      startScanning();
      connectDatabase();
      editCloneData();
      new WpstgCloneEdit();
      new WpstgRemoteStorage();
      new WpstgCloneGenerateLoginLink();
      new WpstgSyncAccount();
      WPStagingBackupEditSchedules$1.listen();
    };

    return that;
  }(jQuery);

  jQuery(document).ready(function ($) {
    WPStagingPro.init();
    jQuery(document).on('click', '#wpstg-update-mail-settings', function (e) {
      e.preventDefault();
      $('#wpstg-update-mail-settings').attr('disabled', 'disabled');
      var data = {
        action: 'wpstg_update_staging_mail_settings',
        emailsAllowed: $('#wpstg_allow_emails').is(':checked'),
        accessToken: wpstg.accessToken,
        nonce: wpstg.nonce
      };
      jQuery.ajax({
        url: ajaxurl,
        type: 'POST',
        data: data,
        error: function error(xhr, textStatus, errorThrown) {
          WPStagingCommon.getSwalModal().fire('Unknown error', 'Please get in contact with us to solve it support@wp-staging.com', 'error');
        },
        success: function success(response) {
          var alertType = 'error';

          if (response.success) {
            alertType = 'success';
          }

          WPStagingCommon.getSwalModal().fire('', response.message, alertType).then(function () {
            jQuery('.wpstg-mails-notice').slideUp('fast');
          });
          $('#wpstg-update-mail-settings').removeAttr('disabled');
          return true;
        },
        statusCode: {
          404: function _() {
            WPStagingCommon.getSwalModal().fire('404', 'Something went wrong; can\'t find ajax request URL! Please get in contact with us to solve it support@wp-staging.com', 'error');
          },
          500: function _() {
            WPStagingCommon.getSwalModal().fire('500', 'Something went wrong; internal server error while processing the request! Please get in contact with us to solve it support@wp-staging.com', 'error');
          }
        }
      });
    });
  }); // export default {}

}());
//# sourceMappingURL=wpstg-admin-pro.js.map
